@@ -17,57 +17,63 @@
 
 #include "chattexteditpart.h"
 
+#include "kopetecontact.h"
 #include "kopetechatsession.h"
 #include "kopeteonlinestatus.h"
 #include "kopeteprotocol.h"
 #include "kopeteglobal.h"
-#include "kopeteprefs.h"
+#include <kopeteappearancesettings.h>
 
 #include <kcompletion.h>
 #include <kdebug.h>
 #include <ktextedit.h>
-#include <ksyntaxhighlighter.h>
 
-#include <qtimer.h>
-#include <qregexp.h>
+#include <QtCore/QTimer>
+#include <QtCore/QRegExp>
 
-ChatTextEditPart::ChatTextEditPart( Kopete::ChatSession *session, QWidget *parent, const char *name )
-	: KopeteRichTextEditPart( parent, name, session->protocol()->capabilities() ), m_session(session)
+ChatTextEditPart::ChatTextEditPart( Kopete::ChatSession *session, QWidget *parent )
+	: KRichTextEditPart(parent, 0, QStringList()), m_session(session)
 {
+	// Set rich support in the part
+	setProtocolRichTextSupport();
+
 	historyPos = -1;
 	
-	toggleAutoSpellCheck(KopetePrefs::prefs()->spellCheck());
-	
 	mComplete = new KCompletion();
 	mComplete->setIgnoreCase( true );
 	mComplete->setOrder( KCompletion::Weighted );
 	
 	// set params on the edit widget
-	edit()->setMinimumSize( QSize( 75, 20 ) );
-	edit()->setWordWrap( QTextEdit::WidgetWidth );
-	edit()->setWrapPolicy( QTextEdit::AtWhiteSpace );
-	edit()->setAutoFormatting( QTextEdit::AutoNone );
+	textEdit()->setMinimumSize( QSize( 75, 20 ) );
+//	textEdit()->setWordWrap( Q3TextEdit::WidgetWidth );
+//	textEdit()->setWrapPolicy( Q3TextEdit::AtWhiteSpace );
+//	textEdit()->setAutoFormatting( Q3TextEdit::AutoNone );
 
 	// some signals and slots connections
-	connect( edit(), SIGNAL( textChanged()), this, SLOT( slotTextChanged() ) );
+	connect( textEdit(), SIGNAL( textChanged()), this, SLOT( slotTextChanged() ) );
 
 	// timers for typing notifications
-	m_typingRepeatTimer = new QTimer(this, "m_typingRepeatTimer");
-	m_typingStopTimer   = new QTimer(this, "m_typingStopTimer");
+	m_typingRepeatTimer = new QTimer(this);
+	m_typingRepeatTimer->setObjectName("m_typingRepeatTimer");
+	m_typingStopTimer   = new QTimer(this);
+	m_typingStopTimer->setObjectName("m_typingStopTimer");
 
 	connect( m_typingRepeatTimer, SIGNAL( timeout() ), this, SLOT( slotRepeatTypingTimer() ) );
 	connect( m_typingStopTimer,   SIGNAL( timeout() ), this, SLOT( slotStoppedTypingTimer() ) );
 
 	connect( session, SIGNAL( contactAdded(const Kopete::Contact*, bool) ),
 	         this, SLOT( slotContactAdded(const Kopete::Contact*) ) );
-	connect( session, SIGNAL( contactRemoved(const Kopete::Contact*, const QString&, Kopete::Message::MessageFormat, bool) ),
+	connect( session, SIGNAL( contactRemoved(const Kopete::Contact*, const QString&, Qt::TextFormat, bool) ),
 	         this, SLOT( slotContactRemoved(const Kopete::Contact*) ) );
 	connect( session, SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus & , const Kopete::OnlineStatus &) ),
 	         this, SLOT( slotContactStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ) );
 	
+	setFont( Kopete::AppearanceSettings::self()->chatFont() );
+
 	slotContactAdded( session->myself() );
-	for ( QPtrListIterator<Kopete::Contact> it( session->members() ); it.current(); ++it )
-		slotContactAdded( *it );
+
+	foreach( Kopete::Contact *contact, session->members() )
+		slotContactAdded( contact );
 }
 
 ChatTextEditPart::~ChatTextEditPart()
@@ -75,38 +81,8 @@ ChatTextEditPart::~ChatTextEditPart()
 	delete mComplete;
 }
 
-KTextEdit *ChatTextEditPart::edit()
-{
-	return static_cast<KTextEdit*>(widget());
-}
-
-void ChatTextEditPart::toggleAutoSpellCheck( bool enabled )
-{
-	if ( richTextEnabled() )
-		enabled = false;
-
-	m_autoSpellCheckEnabled = enabled;
-	if ( spellHighlighter() )
-	{
-		spellHighlighter()->setAutomatic( enabled );
-		spellHighlighter()->setActive( enabled );
-	}
-	edit()->setCheckSpellingEnabled( enabled );
-}
-
-bool ChatTextEditPart::autoSpellCheckEnabled() const
-{
-	return m_autoSpellCheckEnabled;
-}
-
-KDictSpellingHighlighter* ChatTextEditPart::spellHighlighter()
-{
-	QSyntaxHighlighter *qsh = edit()->syntaxHighlighter();
-	KDictSpellingHighlighter* kdsh = dynamic_cast<KDictSpellingHighlighter*>( qsh );
-	return kdsh;
-}
-
 // NAUGHTY, BAD AND WRONG! (but needed to fix nick complete bugs)
+/*
 #include <private/qrichtext_p.h>
 class EvilTextEdit : public KTextEdit
 {
@@ -119,31 +95,36 @@ public:
 		return str.left( str.length() - 1 );
 	}
 };
-
+*/
 void ChatTextEditPart::complete()
 {
+#ifdef __GNUC__
+#warning disabled nick completion to make it compile
+#endif
+#if 0
 	int para = 1, parIdx = 1;
-	edit()->getCursorPosition( &para, &parIdx);
+	textEdit()->getCursorPosition( &para, &parIdx);
 
 	// FIXME: strips out all formatting
-	QString txt = static_cast<EvilTextEdit*>(edit())->plainText( para );
+//QString txt = static_cast<EvilTextEdit*>(textEdit())->plainText( para );
+	QString txt = textEdit()->text(para);
 
 	if ( parIdx > 0 )
 	{
-		int firstSpace = txt.findRev( QRegExp( QString::fromLatin1("\\s\\S+") ), parIdx - 1 ) + 1;
-		int lastSpace = txt.find( QRegExp( QString::fromLatin1("[\\s\\:]") ), firstSpace );
+		int firstSpace = txt.lastIndexOf( QRegExp( QLatin1String("\\s\\S+") ), parIdx - 1 ) + 1;
+		int lastSpace = txt.find( QRegExp( QLatin1String("[\\s\\:]") ), firstSpace );
 		if( lastSpace == -1 )
 			lastSpace = txt.length();
 
 		QString word = txt.mid( firstSpace, lastSpace - firstSpace );
 		QString match;
 
-		kdDebug(14000) << k_funcinfo << word << " from '" << txt << "'" << endl;
+		kDebug(14000) << word << " from '" << txt << "'";
 
 		if ( word != m_lastMatch )
 		{
 			match = mComplete->makeCompletion( word );
-			m_lastMatch = QString::null;
+			m_lastMatch.clear();
 			parIdx -= word.length();
 		}
 		else
@@ -158,7 +139,7 @@ void ChatTextEditPart::complete()
 
 			if ( para == 0 && firstSpace == 0 && rightText[0] != QChar(':') )
 			{
-				rightText = match + QString::fromLatin1(": ") + rightText;
+				rightText = match + QLatin1String(": ") + rightText;
 				parIdx += 2;
 			}
 			else
@@ -167,23 +148,24 @@ void ChatTextEditPart::complete()
 			// insert *before* remove. this is becase Qt adds an extra blank line
 			// if the rich text control becomes empty (if you remove the only para).
 			// disable updates while we change the contents to eliminate flicker.
-			edit()->setUpdatesEnabled( false );
-			edit()->insertParagraph( txt.left(firstSpace) + rightText, para );
-			edit()->removeParagraph( para + 1 );
-			edit()->setCursorPosition( para, parIdx + match.length() );
-			edit()->setUpdatesEnabled( true );
+			textEdit()->setUpdatesEnabled( false );
+			textEdit()->insertParagraph( txt.left(firstSpace) + rightText, para );
+			textEdit()->removeParagraph( para + 1 );
+			textEdit()->setCursorPosition( para, parIdx + match.length() );
+			textEdit()->setUpdatesEnabled( true );
 			// must call this rather than update because QTextEdit is broken :(
-			edit()->updateContents();
+			textEdit()->updateContents();
 			m_lastMatch = match;
 		}
 		else
 		{
-			kdDebug(14000) << k_funcinfo << "No completions! Tried " << mComplete->items() << endl;
+			kDebug(14000) << "No completions! Tried " << mComplete->items();
 		}
 	}
+#endif
 }
 
-void ChatTextEditPart::slotPropertyChanged( Kopete::Contact*, const QString &key,
+void ChatTextEditPart::slotPropertyChanged( Kopete::PropertyContainer*, const QString &key,
 		const QVariant& oldValue, const QVariant &newValue  )
 {
 	if ( key == Kopete::Global::Properties::self()->nickName().key() )
@@ -195,8 +177,8 @@ void ChatTextEditPart::slotPropertyChanged( Kopete::Contact*, const QString &key
 
 void ChatTextEditPart::slotContactAdded( const Kopete::Contact *contact )
 {
-	connect( contact, SIGNAL( propertyChanged( Kopete::Contact *, const QString &, const QVariant &, const QVariant & ) ),
-	         this, SLOT( slotPropertyChanged( Kopete::Contact *, const QString &, const QVariant &, const QVariant & ) ) ) ;
+	connect( contact, SIGNAL( propertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ),
+	         this, SLOT( slotPropertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ) ) ;
 	
 	QString contactName = contact->property(Kopete::Global::Properties::self()->nickName()).value().toString();
 	mComplete->addItem( contactName );
@@ -204,8 +186,8 @@ void ChatTextEditPart::slotContactAdded( const Kopete::Contact *contact )
 
 void ChatTextEditPart::slotContactRemoved( const Kopete::Contact *contact )
 {
-	disconnect( contact, SIGNAL( propertyChanged( Kopete::Contact *, const QString &, const QVariant &, const QVariant & ) ),
-	            this, SLOT( slotPropertyChanged( Kopete::Contact *, const QString &, const QVariant &, const QVariant & ) ) ) ;
+	disconnect( contact, SIGNAL( propertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ),
+	            this, SLOT( slotPropertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ) ) ;
 	
 	QString contactName = contact->property(Kopete::Global::Properties::self()->nickName()).value().toString();
 	mComplete->removeItem( contactName );
@@ -213,10 +195,12 @@ void ChatTextEditPart::slotContactRemoved( const Kopete::Contact *contact )
 
 bool ChatTextEditPart::canSend()
 {
+	int i;
+	
 	if ( !m_session ) return false;
 
 	// can't send if there's nothing *to* send...
-	if ( edit()->text().isEmpty() )
+	if ( text(Qt::PlainText).isEmpty() )
 		return false;
 
 	Kopete::ContactPtrList members = m_session->members();
@@ -227,10 +211,9 @@ bool ChatTextEditPart::canSend()
 		bool reachableContactFound = false;
 
 		//TODO: does this perform badly in large / busy IRC channels? - no, doesn't seem to
-		QPtrListIterator<Kopete::Contact> it ( members );
-		for( ; it.current(); ++it )
+		for( i = 0; i != members.size(); i++ )
 		{
-			if ( (*it)->isReachable() )
+			if ( members[i]->isReachable() )
 			{
 				reachableContactFound = true;
 				break;
@@ -257,19 +240,19 @@ void ChatTextEditPart::slotContactStatusChanged( Kopete::Contact *, const Kopete
 
 void ChatTextEditPart::sendMessage()
 {
-	QString txt = text( Qt::PlainText );
+	QString txt = this->text( Qt::PlainText );
 	// avoid sending emtpy messages or enter keys (see bug 100334)
 	if ( txt.isEmpty() || txt == "\n" )
 		return;
 
-	if ( m_lastMatch.isNull() && ( txt.find( QRegExp( QString::fromLatin1("^\\w+:\\s") ) ) > -1 ) )
+	if ( m_lastMatch.isNull() && ( txt.indexOf( QRegExp( QLatin1String("^\\w+:\\s") ) ) > -1 ) )
 	{ //no last match and it finds something of the form of "word:" at the start of a line
-		QString search = txt.left( txt.find(':') );
+		QString search = txt.left( txt.indexOf(':') );
 		if( !search.isEmpty() )
 		{
 			QString match = mComplete->makeCompletion( search );
 			if( !match.isNull() )
-				edit()->setText( txt.replace(0,search.length(),match) );
+				textEdit()->setText( txt.replace(0,search.length(),match) );
 		}
 	}
 
@@ -277,13 +260,13 @@ void ChatTextEditPart::sendMessage()
 	{
 		//FIXME: what is the next line for?
 		mComplete->addItem( m_lastMatch );
-		m_lastMatch = QString::null;
+		m_lastMatch.clear();
 	}
 
 	slotStoppedTypingTimer();
 	Kopete::Message sentMessage = contents();
 	emit messageSent( sentMessage );
-	historyList.prepend( edit()->text() );
+	historyList.prepend( this->text( Qt::PlainText) );
 	historyPos = -1;
 	clear();
 	emit canSendChanged( false );
@@ -296,7 +279,7 @@ bool ChatTextEditPart::isTyping()
 	//Make sure the message is empty. QString::isEmpty()
 	//returns false if a message contains just whitespace
 	//which is the reason why we strip the whitespace	
-	return !txt.stripWhiteSpace().isEmpty();
+	return !txt.trimmed().isEmpty();
 }
 
 void ChatTextEditPart::slotTextChanged()
@@ -306,12 +289,14 @@ void ChatTextEditPart::slotTextChanged()
 		// And they were previously typing
 		if( !m_typingRepeatTimer->isActive() )
 		{
-			m_typingRepeatTimer->start( 4000, false );
+			m_typingRepeatTimer->setSingleShot( false );
+			m_typingRepeatTimer->start( 4000 );
 			slotRepeatTypingTimer();
 		}
 
 		// Reset the stop timer again, regardless of status
-		m_typingStopTimer->start( 4500, true );
+		m_typingStopTimer->setSingleShot( true );
+		m_typingStopTimer->start( 4500 );
 	}
 
 	emit canSendChanged( canSend() );
@@ -322,8 +307,8 @@ void ChatTextEditPart::historyUp()
 	if ( historyList.empty() || historyPos == historyList.count() - 1 )
 		return;
 	
-	QString text = edit()->text();
-	bool empty = text.stripWhiteSpace().isEmpty();
+	QString text = this->text(Qt::PlainText);
+	bool empty = text.trimmed().isEmpty();
 	
 	// got text? save it
 	if ( !empty )
@@ -342,11 +327,11 @@ void ChatTextEditPart::historyUp()
 	historyPos++;
 	
 	QString newText = historyList[historyPos];
-	TextFormat format=edit()->textFormat();
-	edit()->setTextFormat(AutoText); //workaround bug 115690
-	edit()->setText( newText );
-	edit()->setTextFormat(format);
-	edit()->moveCursor( QTextEdit::MoveEnd, false );
+// 	TextFormat format=textEdit()->textFormat();
+// 	textEdit()->setTextFormat(AutoText); //workaround bug 115690
+	textEdit()->setText( newText );
+// 	textEdit()->setTextFormat(format);
+	textEdit()->moveCursor( QTextCursor::End );
 }
 
 void ChatTextEditPart::historyDown()
@@ -354,8 +339,8 @@ void ChatTextEditPart::historyDown()
 	if ( historyList.empty() || historyPos == -1 )
 		return;
 	
-	QString text = edit()->text();
-	bool empty = text.stripWhiteSpace().isEmpty();
+	QString text = this->text(Qt::PlainText);
+	bool empty = text.trimmed().isEmpty();
 	
 	// got text? save it
 	if ( !empty )
@@ -365,41 +350,49 @@ void ChatTextEditPart::historyDown()
 	
 	historyPos--;
 	
-	QString newText = ( historyPos >= 0 ? historyList[historyPos] : QString::null );
+	QString newText = ( historyPos >= 0 ? historyList[historyPos] : QString() );
 	
 	
-	TextFormat format=edit()->textFormat();
-	edit()->setTextFormat(AutoText); //workaround bug 115690
-	edit()->setText( newText );
-	edit()->setTextFormat(format);
-	
-	
-	
-	edit()->moveCursor( QTextEdit::MoveEnd, false );
+// 	TextFormat format=textEdit()->textFormat();
+// 	textEdit()->setTextFormat(AutoText); //workaround bug 115690
+	textEdit()->setText( newText );
+// 	textEdit()->setTextFormat(format);
+	textEdit()->moveCursor( QTextCursor::End );
 }
 
 void ChatTextEditPart::addText( const QString &text )
 {
-	edit()->insert( text );
+	if( Qt::mightBeRichText(text) )
+	{
+		textEdit()->insertHtml( text );
+	}
+	else
+	{
+		textEdit()->insertPlainText( text );
+	}
 }
 
 void ChatTextEditPart::setContents( const Kopete::Message &message )
 {
-	edit()->setText( richTextEnabled() ? message.escapedBody() : message.plainBody() );
-
+	if ( useRichText() )
+		textEdit()->setHtml ( message.escapedBody() );
+	else
+		textEdit()->setPlainText ( message.plainBody() );
+	textEdit()->moveCursor ( QTextCursor::End );
+	
 	setFont( message.font() );
-	setFgColor( message.fg() );
-	setBgColor( message.bg() );
+	setTextColor( message.foregroundColor() );
+// 	setBackgroundColorColor( message.backgroundColor() );
 }
 
 Kopete::Message ChatTextEditPart::contents()
 {
-	Kopete::Message currentMsg( m_session->myself(), m_session->members(), edit()->text(),
-	                            Kopete::Message::Outbound, richTextEnabled() ?
-	                            Kopete::Message::RichText : Kopete::Message::PlainText );
+	Kopete::Message currentMsg( m_session->myself(), m_session->members() );
+	currentMsg.setDirection( Kopete::Message::Outbound );
+	useRichText() ? currentMsg.setHtmlBody( text() ) : currentMsg.setPlainBody( text() );
 	
-	currentMsg.setBg( bgColor() );
-	currentMsg.setFg( fgColor() );
+// 	currentMsg.setBackgroundColor( bgColor() );
+	currentMsg.setForegroundColor( textColor() );
 	currentMsg.setFont( font() );
 	
 	return currentMsg;
@@ -417,7 +410,46 @@ void ChatTextEditPart::slotStoppedTypingTimer()
 	emit typing( false );
 }
 
+void ChatTextEditPart::setProtocolRichTextSupport()
+{
+	KRichTextEditPart::RichTextSupport richText;
+	Kopete::Protocol::Capabilities protocolCaps = m_session->protocol()->capabilities();
+
+	// Check for bold
+	if( (protocolCaps & Kopete::Protocol::BaseBFormatting) || (protocolCaps & Kopete::Protocol::RichBFormatting) )
+	{
+		richText |= KRichTextEditPart::SupportBold;
+	}
+	// Check for italic
+	if( (protocolCaps & Kopete::Protocol::BaseIFormatting) || (protocolCaps & Kopete::Protocol::RichIFormatting) )
+	{
+		richText |= KRichTextEditPart::SupportItalic;
+	}
+	// Check for underline
+	if( (protocolCaps & Kopete::Protocol::BaseUFormatting) || (protocolCaps & Kopete::Protocol::RichUFormatting) )
+	{
+		richText |= KRichTextEditPart::SupportUnderline;
+	}
+	// Check for font support
+	if( (protocolCaps & Kopete::Protocol::BaseFont) || (protocolCaps & Kopete::Protocol::RichFont) )
+	{
+		richText |= KRichTextEditPart::SupportFont;
+	}
+	// Check for text color support
+	if( (protocolCaps & Kopete::Protocol::BaseFgColor) || (protocolCaps & Kopete::Protocol::RichFgColor) )
+	{
+		richText |= KRichTextEditPart::SupportTextColor;
+	}
+	// Check for alignment
+	if( protocolCaps & Kopete::Protocol::Alignment )
+	{
+		richText |= KRichTextEditPart::SupportAlignment;
+	}
+
+	// Set rich text support in KRichTextEditPart
+	setRichTextSupport( richText );
+}
+
 #include "chattexteditpart.moc"
 
 // vim: set noet ts=4 sts=4 sw=4:
-
