@@ -104,7 +104,6 @@ KopeteApplication::~KopeteApplication()
 
 	delete m_fileEngineHandler;
 	delete m_emoticonHandler;
-	delete m_mainWindow;
 	//kDebug( 14000 ) << "Done";
 }
 
@@ -311,6 +310,12 @@ void KopeteApplication::quitKopete()
 			break;
 		}
 	}
+
+	if ( m_isShuttingDown && m_mainWindow )
+	{
+		m_mainWindow->deleteLater();
+		m_mainWindow = 0;
+	}
 }
 
 
