@@ -2,7 +2,7 @@
     kopetecontactlist.h - Kopete's Contact List backend
 
     Copyright (c) 2002      by Martijn Klingens       <klingens@kde.org>
-    Copyright (c) 2002-2004 by Olivier Goffart        <ogoffart@tiscalinet.be>
+    Copyright (c) 2002-2004 by Olivier Goffart        <ogoffart@kde.org>
 
     Kopete    (c) 2002-2004 by the Kopete developers  <kopete-devel@kde.org>
 
@@ -19,14 +19,12 @@
 #ifndef KOPETECONTACTLIST_H__
 #define KOPETECONTACTLIST_H__
 
-#include <qobject.h>
-#include <qptrlist.h>
+#include <QtCore/QObject>
+#include <QtCore/QList>
 
-#include <kopete_export.h>
-
-class KURL;
-class QDomDocument;
+#include <kurl.h>
 
+#include "kopete_export.h"
 
 namespace Kopete 
 {
@@ -41,11 +39,11 @@ class Contact;
  *
  * The contactList is a singleton you can uses with @ref ContactList::self()
  *
- * it let you get a list of metacontact with @ref metaContacts()
- * Only metacontact which are on the contactlist are returned.
+ * it let you get a list of metacontact with metaContacts()
+ * Only metacontact which are on the contact list are returned.
  *
  * @author Martijn Klingens <klingens@kde.org>
- * @author Olivier Goffart <ogoffart @tiscalinet.be>
+ * @author Olivier Goffart <ogoffart@tiscalinet.be>
  */
 class KOPETE_EXPORT ContactList : public QObject
 {
@@ -60,7 +58,7 @@ public:
 	~ContactList();
 
 	/**
-	 * @brief return a list of all metacontact of the contactlist
+	 * @brief return a list of all metacontact of the contact list
 	 * Retrieve the list of all available meta contacts.
 	 * The returned QPtrList is not the internally used variable, so changes
 	 * to it won't propagate into the actual contact list. This can be
@@ -70,12 +68,12 @@ public:
 	 * The contained MetaContacts are obviously _not_ duplicates, so
 	 * changing those *will* have the expected result :-)
 	 */
-	QPtrList<MetaContact> metaContacts() const;
+	QList<MetaContact *> metaContacts() const;
 	
 	/**
 	 * @return all groups
 	 */
-	QPtrList<Group> groups() const;
+	QList<Group *> groups() const;
 
 	/**
 	 * Return the metacontact referenced by the given id. is none is found, return 0L
@@ -90,7 +88,7 @@ public:
 	
 	
 	/**
-	 * @brief find a contact in the contactlist.
+	 * @brief find a contact in the contact list.
 	 * Browse in each metacontact of the list to find the contact with the given ID.
 	 * @param protocolId the @ref Plugin::pluginId() of the protocol ("MSNProtocol")
 	 * @param accountId the @ref Account::accountId()
@@ -114,22 +112,37 @@ public:
 	 * If a group already exists with the given name and the given type, the existing group will be returned.
  	 * Otherwise, a new group will be created.
 	 * @param displayName is the display name to search
-	 * @param type is the @ref Group::GroupType to search, the default value is group::Normal
+	 * @param type is the Group::GroupType to search, the default value is group::Normal
 	 * @return always a valid Group
 	 */
 	Group * findGroup( const QString &displayName, int type = 0/*Group::Normal*/ );
 
 	/**
-	 * return the list of metacontact actually selected in the contactlist UI
+	 * return the list of metacontact actually selected in the contact list UI
 	 */
-	QPtrList<MetaContact> selectedMetaContacts() const;
+	QList<MetaContact *> selectedMetaContacts() const;
 
 	/**
-	 * return the list of groups actualy selected in the contactlist UI
+	 * return the list of groups actualy selected in the contact list UI
 	 */
-	QPtrList<Group> selectedGroups() const ;
-	
+	QList<Group *> selectedGroups() const ;
+
+	/**
+	  * return the metacontact that represent the user itself.
+	  * This metacontact should be the parent of every Kopete::Account::myself() contacts.
+	  *
+	  * This metacontact is not in the contact list.
+	  */
+	MetaContact* myself();
+
 public slots:
+	/**
+	 * Add metacontacts into the contact list
+	 * When calling this method, contacts have to be already placed in the correct group.
+	 * If contacts are not in a group, they will be added to the top-level group.
+	 * It is also better if the MetaContacts could also be completely created, i.e: all contacts already in it
+	 */
+	void addMetaContacts( QList<MetaContact *> metaContacts );
 
 	/**
 	 * Add the metacontact into the contact list
@@ -140,11 +153,17 @@ public slots:
 	void addMetaContact( Kopete::MetaContact *c );
 
 	/**
-	 * Remove a metacontact from the contactlist.
+	 * Remove a metacontact from the contact list.
 	 * This method delete itself the metacontact.
 	 */
 	void removeMetaContact( Kopete::MetaContact *contact );
 
+	/**
+	 * Add groups
+	 * each group must be added on the list after his creation.
+	 */
+	void addGroups( QList<Group *> groups );
+
 	/**
 	 * Add a group
 	 * each group must be added on the list after his creation.
@@ -159,10 +178,18 @@ public slots:
 
 	/**
 	 * Set which items are selected in the ContactList GUI.
-	 * This method has to be called by the contactlist UI side.
+	 * This method has to be called by the contact list UI side.
 	 * it stores the selected items, and emits signals
 	 */
-	 void setSelectedItems(QPtrList<MetaContact> metaContacts , QPtrList<Group> groups);
+	 void setSelectedItems(QList<MetaContact *> metaContacts , QList<Group *> groups);
+
+	/**
+	 * @internal
+	 * Load the contact list
+	 */
+	void load();
+
+	void save();
 
 signals:
 	/**
@@ -219,17 +246,11 @@ private slots:
 	 */
 	void slotSaveLater();
 	/**
-	 * Called on contactlist load or when KABC has changed, to check if we need to update our contactlist from there.
+	 * Called on contact list load or when KABC has changed, to check if we need to update our contact list from there.
 	 */
 	void slotKABCChanged();
+
 private:
-	
-	/**
-	 * Convert the contact list from an older version
-	 */
-	void convertContactList( const QString &fileName, uint fromVersion, uint toVersion );
-	
-	
 	/**
 	 * Private constructor: we are a singleton
 	 */
@@ -238,107 +259,6 @@ private:
 	static ContactList *s_self;
 	class Private;
 	Private *d;
-	
-
-public: //TODO I think all theses method should be moved to the decop interface.
-	/**
-	 * Return all meta contacts
-	 */
-	QStringList contacts() const;
-
-	/**
-	 * Return all meta contacts that are reachable
-	 */
-	QStringList reachableContacts() const;
-
-	/**
-	 * Return all contacts that are online
-	 */
-	QPtrList<Contact> onlineContacts() const;
-
-	/**
-	 * Overloaded method of @ref onlineContacts() that only returns
-	 * the online contacts for a single protocol
-	 */
-	QPtrList<Contact> onlineContacts( const QString &protocolId ) const;
-
-	/**
-	 * Return all meta contacts that are online
-	 */
-	QPtrList<MetaContact> onlineMetaContacts() const;
-
-	/**
-	 * Overloaded method of @ref onlineMetaContacts() that only returns
-	 * the online meta contacts for a single protocol
-	 */
-	QPtrList<MetaContact> onlineMetaContacts( const QString &protocolId ) const;
-
-	/**
-	 * Returns all contacts which can accept file transfers
-	 */
-	QStringList fileTransferContacts() const;
-
-	QStringList contactFileProtocols( const QString &displayName);
-
-	/**
-	 * Return all meta contacts with their current status
-	 *
-	 * FIXME: Do we *need* this one? Sounds error prone to me, because
-	 * nicknames can contain parentheses too. - Martijn
-	 */
-	QStringList contactStatuses() const;
-	
-	
-	/**
-	 * Exposed via DCOP in kopeteiface
-	 * Used to send a file to a MetaContact using the highest ranked protocol
-	 *
-	 * FIXME: We need to change this to use a unique ID instead of the displayName
-	 *
-	 * @param displayName Metacontact to send file to
-	 * @param sourceURL The file we are sending
-	 * @param altFileName (Optional) An alternate filename for the file we are sending
-	 * @param fileSize (Optional) The size of the file
-	 */
-	void sendFile(const QString &displayName, const KURL &sourceURL,
-		const QString &altFileName = QString::null, const long unsigned int fileSize = 0L);
-
-	/**
-	 * Open a chat to a contact, and optionally set some initial text
-	 */
-	void messageContact( const QString &displayName, const QString &messageText = QString::null );
-
-	
-	
-
-public slots:
-	/**
-	 * @internal
-	 * Load the contact list
-	 *
-	 * FIXME: Use a better way, without exposing the XML backend, though.
-	 */
-	void load();
-
-	void save();
-	
-private:
-	/**
-	 * Return a XML representation of the contact list
-	 */
-	const QDomDocument toXML();
-
-	/**
-	 * Load the contact list from XML file
-	 */
-	void loadXML();
-
-	/**
-	 * Save the contact list to XML file
-	 */
-	void saveXML();
-	
-	
 };
 
 } //END namespace Kopete
