@@ -17,7 +17,7 @@
 #include "kopetemessagehandler.h"
 #include "kopetemessageevent.h"
 
-#include <kstaticdeleter.h>
+#include <kglobal.h>
 
 namespace Kopete
 {
@@ -76,26 +76,24 @@ class MessageHandlerFactory::Private
 {
 public:
 	static FactoryList &factories();
+	FactoryList::Iterator iterator;
 };
 
-MessageHandlerFactory::FactoryList &MessageHandlerFactory::Private::factories()
+K_GLOBAL_STATIC(MessageHandlerFactory::FactoryList, g_list)
+MessageHandlerFactory::FactoryList& MessageHandlerFactory::Private::factories()
 {
-	static KStaticDeleter<FactoryList> deleter;
-	static FactoryList *list = 0;
-	if( !list )
-		deleter.setObject( list, new FactoryList );
-	return *list;
+	return *g_list;
 }
 
 MessageHandlerFactory::MessageHandlerFactory()
 	: d( new Private )
 {
-	Private::factories().append(this);
+	d->iterator = Private::factories().insert( Private::factories().end(), (this));
 }
 
 MessageHandlerFactory::~MessageHandlerFactory()
 {
-	Private::factories().remove( this );
+ 	Private::factories().erase( d->iterator );
 	delete d;
 }
 
