@@ -285,7 +285,7 @@ void KopeteViewManager::messageAppended( Kopete::Message &msg, Kopete::ChatSessi
 		Kopete::MessageEvent *event = 0L;
 		if ( (appendMessageEvent && !outgoingMessage) || showNotification )
 		{
-			showNotification = showNotification || d->eventList.isEmpty(); // may happen for internal messages
+			showNotification = showNotification || (msg.from() && d->eventList.isEmpty()); // may happen for internal messages
 			event = new Kopete::MessageEvent(msg,manager);
 			d->eventList.append( event );
 
@@ -363,7 +363,8 @@ void KopeteViewManager::messageAppended( Kopete::Message &msg, Kopete::ChatSessi
 			view->raise();
 		}
 
-		if( (appendMessageEvent || !isActiveWindow) && event )
+		bool animateOnMessageWithOpenChat = Kopete::BehaviorSettings::self()->animateOnMessageWithOpenChat();
+		if ( event && ( appendMessageEvent || ( animateOnMessageWithOpenChat && !isActiveWindow ) ) )
 			Kopete::ChatSessionManager::self()->postNewEvent(event);
 	}
 }
