@@ -21,10 +21,12 @@
 
 #undef KDE_NO_COMPAT
 #include <kaction.h>
-#include <qobject.h>
+#include <QtCore/QObject>
 
 #include "kopete_export.h"
 
+class KActionCollection;
+class KIcon;
 /**
  * @author Ryan Cumming <bodnar42@phalynx.dhs.org>
  */
@@ -35,57 +37,57 @@ public:
 	 * Standard action to start a chat
 	 */
 	static KAction *chat( const QObject *recvr, const char *slot,
-		QObject* parent, const char *name = 0 );
+		KActionCollection* parent, const char *name = 0 );
 	/**
 	 * Standard action to send a single message
 	 */
 	static KAction *sendMessage(const QObject *recvr, const char *slot,
-		QObject* parent, const char *name = 0);
+		KActionCollection* parent, const char *name = 0);
 	/**
 	 * Standard action to open a user info dialog
 	 */
 	static KAction *contactInfo(const QObject *recvr, const char *slot,
-		QObject* parent, const char *name = 0);
+		KActionCollection* parent, const char *name = 0);
 	/**
 	 * Standard action to open a history dialog or something similar
 	 */
 	static KAction *viewHistory(const QObject *recvr, const char *slot,
-		QObject* parent, const char *name = 0);
+		KActionCollection* parent, const char *name = 0);
 	/**
 	 * Standard action to initiate sending a file to a contact
 	 */
 	static KAction *sendFile(const QObject *recvr, const char *slot,
-		QObject* parent, const char *name = 0);
+		KActionCollection* parent, const char *name = 0);
 	/**
 	 * Standard action to change a contacts @ref Kopete::MetaContact
 	 */
 	static KAction *changeMetaContact(const QObject *recvr, const char *slot,
-		QObject* parent, const char *name = 0);
+		KActionCollection* parent, const char *name = 0);
 	/**
 	 * Standard action to add a group
 	 */
 	static KAction *addGroup(const QObject *recvr, const char *slot,
-		QObject* parent, const char *name = 0);
+		KActionCollection* parent, const char *name = 0);
 	/**
 	 * Standard action to delete a contact
 	 */
 	static KAction *deleteContact(const QObject *recvr, const char *slot,
-		QObject* parent, const char *name = 0);
+		KActionCollection* parent, const char *name = 0);
 	/**
-	 * Standard action to change a contact alias/nickname in your contactlist
+	 * Standard action to change a contact alias/nickname in your contact list
 	 */
 	static KAction *changeAlias(const QObject *recvr, const char *slot,
-		QObject* parent, const char *name = 0);
+		KActionCollection* parent, const char *name = 0);
 	/**
 	 * Standard action to block a contact
 	 */
 	static KAction *blockContact(const QObject *recvr, const char *slot,
-		QObject* parent, const char *name = 0);
+		KActionCollection* parent, const char *name = 0);
 	/**
 	 * Standard action to unblock a contact
 	 */
 	static KAction *unblockContact(const QObject *recvr, const char *slot,
-		QObject* parent, const char *name = 0);
+		KActionCollection* parent, const char *name = 0);
 
 	/**
 	 * Return an action to change the Kopete preferences.
@@ -93,6 +95,12 @@ public:
 	 * The object has no signal/slot, the prefs are automatically shown
 	 */
 	static KAction *preferences(KActionCollection *parent, const char *name = 0);
+private:
+	/**
+	 * @internal
+	 * Helper method to create a action
+	 */
+	static KAction *createAction(const QString &text, const KIcon &icon, const QObject *receiver, const char *slot, KActionCollection* parent, const char *name);
 };
 
 
@@ -106,7 +114,7 @@ class KOPETE_EXPORT KopetePreferencesAction : public KAction
 	  Q_OBJECT
 
 	  public:
-			 KopetePreferencesAction( KActionCollection *parent, const char *name = 0 );
+			 explicit KopetePreferencesAction( KActionCollection *parent, const char *name = 0 );
 			 ~KopetePreferencesAction();
 
 	  protected slots:
