@@ -21,7 +21,9 @@
 #include <kconfig.h>
 #include <kglobal.h>
 #include <klocale.h>
+#include <kconfiggroup.h>
 
+//TODO: Use KConfigXT
 AutoReplaceConfig::AutoReplaceConfig()
 {
 	load();
@@ -30,10 +32,9 @@ AutoReplaceConfig::AutoReplaceConfig()
 // reload configuration reading it from kopeterc
 void AutoReplaceConfig::load()
 {
-	KConfig *config = KGlobal::config();
-	config->setGroup( "AutoReplace Plugin" );
+	KConfigGroup config(KGlobal::config(), "AutoReplace Plugin");
 
-	QStringList wordsList = config->readListEntry( "WordsToReplace" );
+	QStringList wordsList = config.readEntry( "WordsToReplace", QStringList() );
 	if( wordsList.isEmpty() )
 	{
 		// basic list, key/value
@@ -55,16 +56,16 @@ void AutoReplaceConfig::load()
 		m_map.insert( k, v );
 	}
 
-	m_autoreplaceIncoming = config->readBoolEntry( "AutoReplaceIncoming" , false );
-	m_autoreplaceOutgoing = config->readBoolEntry( "AutoReplaceOutgoing" , true );
-	m_addDot              = config->readBoolEntry( "DotEndSentence" , false );
-	m_upper               = config->readBoolEntry( "CapitalizeBeginningSentence" , false );
+	m_autoreplaceIncoming = config.readEntry( "AutoReplaceIncoming" , false );
+	m_autoreplaceOutgoing = config.readEntry( "AutoReplaceOutgoing" , true );
+	m_addDot              = config.readEntry( "DotEndSentence" , false );
+	m_upper               = config.readEntry( "CapitalizeBeginningSentence" , false );
 }
 
 QStringList AutoReplaceConfig::defaultAutoReplaceList()
 {
-    return QStringList::split( ",", i18n( "list_of_words_to_replace",
-			"ur,your,r,are,u,you,theres,there is,arent,are not,dont,do not" ) );
+    return i18nc( "list_of_words_to_replace",
+			"ur,your,r,are,u,you,theres,there is,arent,are not,dont,do not" ).split( ",", QString::SkipEmptyParts );
 }
 
 void AutoReplaceConfig::loadDefaultAutoReplaceList()
@@ -101,6 +102,27 @@ bool AutoReplaceConfig::capitalizeBeginningSentence() const
 	return m_upper;
 }
 
+void AutoReplaceConfig::setAutoReplaceIncoming(bool enabled)
+{
+	m_autoreplaceIncoming = enabled;
+}
+
+void AutoReplaceConfig::setAutoReplaceOutgoing(bool enabled)
+{
+	m_autoreplaceOutgoing = enabled;
+}
+
+void AutoReplaceConfig::setDotEndSentence(bool enabled)
+{
+	m_addDot = enabled;
+}
+
+void AutoReplaceConfig::setCapitalizeBeginningSentence(bool enabled)
+{
+	m_upper = enabled;
+}
+
+
 void AutoReplaceConfig::setMap( const WordsToReplace &w )
 {
 	m_map = w;
@@ -113,20 +135,24 @@ AutoReplaceConfig::WordsToReplace AutoReplaceConfig::map() const
 
 void AutoReplaceConfig::save()
 {
-	KConfig * config = KGlobal::config();
-	config->setGroup( "AutoReplace Plugin" );
+	KConfigGroup config(KGlobal::config(), "AutoReplace Plugin" );
 
 	QStringList newWords;
 	WordsToReplace::Iterator it;
 	for ( it = m_map.begin(); it != m_map.end(); ++it )
 	{
 		newWords.append( it.key() );
-		newWords.append( it.data() );
+		newWords.append( it.value() );
 	}
 
-	config->writeEntry( "WordsToReplace", newWords );
+	config.writeEntry( "WordsToReplace", newWords );
 
-	config->sync();
+	config.writeEntry( "AutoReplaceIncoming" , m_autoreplaceIncoming );
+	config.writeEntry( "AutoReplaceOutgoing" , m_autoreplaceOutgoing );
+	config.writeEntry( "DotEndSentence" , m_addDot );
+	config.writeEntry( "CapitalizeBeginningSentence" , m_upper );
+
+	config.sync();
 }
 
 // vim: set noet ts=4 sts=4 sw=4:
