@@ -1,7 +1,7 @@
 /*
     historylogger.cpp
 
-    Copyright (c) 2003-2004 by Olivier Goffart        <ogoffart @ kde.org>
+    Copyright (c) 2003-2004 by Olivier Goffart        <ogoffart@kde.org>
 
     Kopete    (c) 2003-2004 by the Kopete developers  <kopete-devel@kde.org>
 
@@ -18,12 +18,15 @@
 #include "historylogger.h"
 #include "historyconfig.h"
 
-#include <qregexp.h>
-#include <qfile.h>
-#include <qdir.h>
-#include <qdatetime.h>
-#include <qdom.h>
-#include <qtimer.h>
+#include <QRegExp>
+#include <QFile>
+#include <QDir>
+#include <QDateTime>
+#include <QtXml> // old qdom.h
+#include <QTimer>
+#include <QTextStream>
+#include <QList>
+#include <QtCore/QDate>
 
 #include <kdebug.h>
 #include <kstandarddirs.h>
@@ -37,8 +40,8 @@
 #include "kopetechatsession.h"
 
 // -----------------------------------------------------------------------------
-HistoryLogger::HistoryLogger( Kopete::MetaContact *m,  QObject *parent, const char *name )
- : QObject(parent, name)
+HistoryLogger::HistoryLogger( Kopete::MetaContact *m,  QObject *parent )
+ : QObject(parent)
 {
 	m_saveTimer=0L;
 	m_saveTimerTime=0;
@@ -47,6 +50,8 @@ HistoryLogger::HistoryLogger( Kopete::MetaContact *m,  QObject *parent, const ch
 	m_cachedMonth=-1;
 	m_realMonth=QDate::currentDate().month();
 	m_oldSens=Default;
+	m_filterCaseSensitive=Qt::CaseSensitive;
+	m_filterRegExp=false;
 
 	//the contact may be destroyed, for example, if the contact changes its metacontact
 	connect(m_metaContact , SIGNAL(destroyed(QObject *)) , this , SLOT(slotMCDeleted()));
@@ -55,8 +60,8 @@ HistoryLogger::HistoryLogger( Kopete::MetaContact *m,  QObject *parent, const ch
 }
 
 
-HistoryLogger::HistoryLogger( Kopete::Contact *c,  QObject *parent, const char *name )
- : QObject(parent, name)
+HistoryLogger::HistoryLogger( Kopete::Contact *c,  QObject *parent )
+ : QObject(parent)
 {
 	m_saveTimer=0L;
 	m_saveTimerTime=0;
@@ -65,6 +70,8 @@ HistoryLogger::HistoryLogger( Kopete::Contact *c,  QObject *parent, const char *
 	m_hideOutgoing=false;
 	m_realMonth=QDate::currentDate().month();
 	m_oldSens=Default;
+	m_filterCaseSensitive=Qt::CaseSensitive;
+	m_filterRegExp=false;
 
 	//the contact may be destroyed, for example, if the contact changes its metacontact
 	connect(m_metaContact , SIGNAL(destroyed(QObject *)) , this , SLOT(slotMCDeleted()));
@@ -108,7 +115,7 @@ void HistoryLogger::setCurrentMonth(int month)
 QDomDocument HistoryLogger::getDocument(const Kopete::Contact *c, unsigned int month , bool canLoad , bool* contain)
 {
 	if(m_realMonth!=QDate::currentDate().month())
-	{ //We changed month, our indice are not correct anymore, clean memory.
+	{ //We changed month, our index is not correct anymore, clean memory.
 	  // or we will see what i called "the 31 midnight bug"(TM) :-)  -Olivier
 		m_documents.clear();
 		m_cachedMonth=-1;
@@ -125,7 +132,7 @@ QDomDocument HistoryLogger::getDocument(const Kopete::Contact *c, unsigned int m
 			return QDomDocument();
 	}
 
-	if(!m_metaContact->contacts().contains(c))
+	if(!m_metaContact->contacts().contains(const_cast<Kopete::Contact*>(c)))
 	{
 		if(contain)
 			*contain=false;
@@ -146,8 +153,9 @@ QDomDocument HistoryLogger::getDocument(const Kopete::Contact *c, unsigned int m
 
 }
 
-QDomDocument HistoryLogger::getDocument(const Kopete::Contact *c, const QDate date , bool canLoad , bool* contain)
+QDomDocument HistoryLogger::getDocument(const Kopete::Contact *contact, const QDate date , bool canLoad , bool* contain)
 {
+	Kopete::Contact *c = const_cast<Kopete::Contact*>(contact);
 	if(!m_metaContact)
 	{ //this may happen if the contact has been moved, and the MC deleted
 		if(c && c->metaContact())
@@ -175,7 +183,7 @@ QDomDocument HistoryLogger::getDocument(const Kopete::Contact *c, const QDate da
 	QDomDocument doc( "Kopete-History" );
 
 	QFile file( FileName );
-	if ( !file.open( IO_ReadOnly ) )
+	if ( !file.open( QIODevice::ReadOnly ) )
 	{
 		if(contain)
 			*contain=false;
@@ -207,7 +215,7 @@ void HistoryLogger::appendMessage( const Kopete::Message &msg , const Kopete::Co
 	const Kopete::Contact *c = ct;
 	if(!c && msg.manager() )
 	{
-		QPtrList<Kopete::Contact> mb=msg.manager()->members() ;
+		QList<Kopete::Contact*> mb=msg.manager()->members() ;
 		c = mb.first();
 	}
 	if(!c)  //If the contact is still not initialized, use the message author.
@@ -223,7 +231,7 @@ void HistoryLogger::appendMessage( const Kopete::Message &msg , const Kopete::Co
 	}
 
 
-	if(!c || !m_metaContact->contacts().contains(c) )
+	if(!c || !m_metaContact->contacts().contains(const_cast<Kopete::Contact*>(c)) )
 	{
 		/*QPtrList<Kopete::Contact> contacts= m_metaContact->contacts();
 		QPtrListIterator<Kopete::Contact> it( contacts );
@@ -237,7 +245,7 @@ void HistoryLogger::appendMessage( const Kopete::Message &msg , const Kopete::Co
 		}*/
 		//if(!c)
 
-		kdWarning(14310) << k_funcinfo << "No contact found in this metacontact to" <<
+		kWarning(14310) << "No contact found in this metacontact to" <<
 			" append in the history" << endl;
 		return;
 	}
@@ -295,7 +303,10 @@ void HistoryLogger::appendMessage( const Kopete::Message &msg , const Kopete::Co
 		connect( m_saveTimer, SIGNAL( timeout() ) , this, SLOT(saveToDisk()) );
 	}
 	if(!m_saveTimer->isActive())
-		m_saveTimer->start( m_saveTimerTime, true /*singleshot*/ );
+	{
+		m_saveTimer->setSingleShot( true );
+		m_saveTimer->start( m_saveTimerTime );
+	}
 }
 
 void HistoryLogger::saveToDisk()
@@ -309,40 +320,39 @@ void HistoryLogger::saveToDisk()
 	t.start(); //mesure the time needed to save.
 
 	KSaveFile file( m_toSaveFileName );
-	if( file.status() == 0 )
+	if( file.open() )
 	{
-		QTextStream *stream = file.textStream();
-		//stream->setEncoding( QTextStream::UnicodeUTF8 ); //???? oui ou non?
-		m_toSaveDocument.save( *stream, 1 );
-		file.close();
+		QTextStream stream ( &file );
+		//stream.setEncoding( QTextStream::UnicodeUTF8 ); //???? oui ou non?
+		m_toSaveDocument.save( stream, 1 );
+		file.finalize();
 
-		m_saveTimerTime=QMIN(t.elapsed()*1000, 300000);
+		m_saveTimerTime=qMin(t.elapsed()*1000, 300000);
 		    //a time 1000 times supperior to the time needed to save.  but with a upper limit of 5 minutes
 		//on a my machine, (2.4Ghz, but old HD) it should take about 10 ms to save the file.
 		// So that would mean save every 10 seconds, which seems to be ok.
 		// But it may take 500 ms if the file to save becomes too big (1Mb).
-		kdDebug(14310) << k_funcinfo << m_toSaveFileName << " saved in " << t.elapsed() << " ms " <<endl ;
+		kDebug(14310) << m_toSaveFileName << " saved in " << t.elapsed() << " ms ";
 
-		m_toSaveFileName=QString::null;
+		m_toSaveFileName.clear();
 		m_toSaveDocument=QDomDocument();
 	}
 	else
-		kdError(14310) << k_funcinfo << "impossible to save the history file " << m_toSaveFileName << endl;
+		kError(14310) << "impossible to save the history file " << m_toSaveFileName << endl;
 
 }
 
-QValueList<Kopete::Message> HistoryLogger::readMessages(QDate date)
+QList<Kopete::Message> HistoryLogger::readMessages(QDate date)
 {
 	QRegExp rxTime("(\\d+) (\\d+):(\\d+)($|:)(\\d*)"); //(with a 0.7.x compatibility)
-	QValueList<Kopete::Message> messages;
+	QList<Kopete::Message> messages;
 
 
-	QPtrList<Kopete::Contact> ct=m_metaContact->contacts();
-	QPtrListIterator<Kopete::Contact> it( ct );
+	QList<Kopete::Contact*> ct=m_metaContact->contacts();
 
-	for( ; it.current(); ++it )
+	foreach(Kopete::Contact* contact, ct)
 	{
-		QDomDocument doc=getDocument(*it,date, true, 0L);
+		QDomDocument doc=getDocument(contact,date, true, 0L);
 		QDomElement docElem = doc.documentElement();
 		QDomNode n = docElem.firstChild();
 
@@ -351,7 +361,7 @@ QValueList<Kopete::Message> HistoryLogger::readMessages(QDate date)
 			QDomElement  msgElem2 = n.toElement();
 			if( !msgElem2.isNull() && msgElem2.tagName()=="msg")
 			{
-				rxTime.search(msgElem2.attribute("time"));
+				rxTime.indexIn(msgElem2.attribute("time"));
 				QDateTime dt( QDate(date.year() , date.month() , rxTime.cap(1).toUInt()), QTime( rxTime.cap(2).toUInt() , rxTime.cap(3).toUInt(), rxTime.cap(5).toUInt()  ) );
 
 				if (dt.date() != date)
@@ -367,22 +377,24 @@ QValueList<Kopete::Message> HistoryLogger::readMessages(QDate date)
 				{ //parse only if we don't hide it
 
 					QString f=msgElem2.attribute("from" );
-					const Kopete::Contact *from=f.isNull()? 0L : (*it)->account()->contacts()[f];
+					const Kopete::Contact *from=f.isNull()? 0L : contact->account()->contacts()[f];
 
 					if(!from)
-						from= dir==Kopete::Message::Inbound ? (*it) : (*it)->account()->myself();
+						from= dir==Kopete::Message::Inbound ? contact : contact->account()->myself();
 
 					Kopete::ContactPtrList to;
-					to.append( dir==Kopete::Message::Inbound ? (*it)->account()->myself() : *it );
+					to.append( dir==Kopete::Message::Inbound ? contact->account()->myself() : contact );
 
-					Kopete::Message msg(dt, from, to, msgElem2.text(), dir);
-					msg.setBody( QString::fromLatin1("<span title=\"%1\">%2</span>")
-							.arg( dt.toString(Qt::LocalDate), msg.escapedBody() ),
-							Kopete::Message::RichText);
+					Kopete::Message msg(from, to);
+					msg.setPlainBody( msgElem2.text() );
+					msg.setHtmlBody( QString::fromLatin1("<span title=\"%1\">%2</span>")
+							.arg( dt.toString(Qt::LocalDate), msg.escapedBody() ));
+					msg.setTimestamp( dt );
+					msg.setDirection( dir );
 				
 
 					// We insert it at the good place, given its date
- 					QValueListIterator<Kopete::Message> msgIt;
+ 					QList<Kopete::Message>::Iterator msgIt;
 					
 					for (msgIt = messages.begin(); msgIt != messages.end(); ++msgIt)
 					{
@@ -400,12 +412,12 @@ QValueList<Kopete::Message> HistoryLogger::readMessages(QDate date)
 	return messages;
 }
 
-QValueList<Kopete::Message> HistoryLogger::readMessages(unsigned int lines,
+QList<Kopete::Message> HistoryLogger::readMessages(int lines,
 	const Kopete::Contact *c, Sens sens, bool reverseOrder, bool colorize)
 {
 	//QDate dd =  QDate::currentDate().addMonths(0-m_currentMonth);
 
-	QValueList<Kopete::Message> messages;
+	QList<Kopete::Message> messages;
 
 	// A regexp useful for this function
 	QRegExp rxTime("(\\d+) (\\d+):(\\d+)($|:)(\\d*)"); //(with a 0.7.x compatibility)
@@ -418,7 +430,7 @@ QValueList<Kopete::Message> HistoryLogger::readMessages(unsigned int lines,
 			return messages;
 	}
 
-	if(c && !m_metaContact->contacts().contains(c) )
+	if(c && !m_metaContact->contacts().contains(const_cast<Kopete::Contact*>(c)) )
 		return messages;
 
 	if(sens ==0 )  //if no sens are selected, just continue in the previous sens
@@ -465,19 +477,19 @@ QValueList<Kopete::Message> HistoryLogger::readMessages(unsigned int lines,
 
 		if(!c && m_metaContact->contacts().count()>1)
 		{ //we have to merge the differents subcontact history
-			QPtrList<Kopete::Contact> ct=m_metaContact->contacts();
-			QPtrListIterator<Kopete::Contact> it( ct );
-			for( ; it.current(); ++it )
+			QList<Kopete::Contact*> ct=m_metaContact->contacts();
+
+			foreach(Kopete::Contact *contact, ct)
 			{ //we loop over each contact. we are searching the contact with the next message with the smallest date,
 			  // it will becomes our current contact, and the contact with the mext message with the second smallest
 			  // date, this date will bocomes the limit.
 
 				QDomNode n;
-				if(m_currentElements.contains(*it))
-					n=m_currentElements[*it];
+				if(m_currentElements.contains(contact))
+					n=m_currentElements[contact];
 				else  //there is not yet "next message" register, so we will take the first  (for the current month)
 				{
-					QDomDocument doc=getDocument(*it,m_currentMonth);
+					QDomDocument doc=getDocument(contact,m_currentMonth);
 					QDomElement docElem = doc.documentElement();
 					n= (sens==Chronological)?docElem.firstChild() : docElem.lastChild();
 
@@ -489,7 +501,7 @@ QValueList<Kopete::Message> HistoryLogger::readMessages(unsigned int lines,
 					QDomElement  msgElem2 = n.toElement();
 					if( !msgElem2.isNull() && msgElem2.tagName()=="msg")
 					{
-						rxTime.search(msgElem2.attribute("time"));
+						rxTime.indexIn(msgElem2.attribute("time"));
 						QDate d=QDate::currentDate().addMonths(0-m_currentMonth);
 						QDateTime dt( QDate(d.year() , d.month() , rxTime.cap(1).toUInt()), QTime( rxTime.cap(2).toUInt() , rxTime.cap(3).toUInt(), rxTime.cap(5).toUInt()  ) );
 						if(!timestamp.isValid() || ((sens==Chronological )? dt < timestamp : dt > timestamp) )
@@ -497,7 +509,7 @@ QValueList<Kopete::Message> HistoryLogger::readMessages(unsigned int lines,
 							timeLimit=timestamp;
 							timestamp=dt;
 							msgElem=msgElem2;
-							currentContact=*it;
+							currentContact=contact;
 
 						}
 						else if(!timeLimit.isValid() || ((sens==Chronological) ? timeLimit > dt : timeLimit < dt) )
@@ -574,38 +586,39 @@ QValueList<Kopete::Message> HistoryLogger::readMessages(unsigned int lines,
 
 				if( m_filter.isNull() || ( m_filterRegExp? msgElem.text().contains(QRegExp(m_filter,m_filterCaseSensitive)) : msgElem.text().contains(m_filter,m_filterCaseSensitive) ))
 				{
+					Q_ASSERT(currentContact);
 					QString f=msgElem.attribute("from" );
-					const Kopete::Contact *from=(f.isNull() || !currentContact) ? 0L : currentContact->account()->contacts()[f];
+					const Kopete::Contact *from=f.isNull() ? 0L : currentContact->account()->contacts()[f];
 
 					if(!from)
 						from= dir==Kopete::Message::Inbound ? currentContact : currentContact->account()->myself();
 
 					Kopete::ContactPtrList to;
-					to.append( dir==Kopete::Message::Inbound ? currentContact->account()->myself() : currentContact );
+					to.append( dir==Kopete::Message::Inbound ? currentContact->account()->myself() : const_cast<Kopete::Contact*>(currentContact) );
 
 					if(!timestamp.isValid())
 					{
 						//parse timestamp only if it was not already parsed
-						rxTime.search(msgElem.attribute("time"));
+						rxTime.indexIn(msgElem.attribute("time"));
 						QDate d=QDate::currentDate().addMonths(0-m_currentMonth);
 						timestamp=QDateTime( QDate(d.year() , d.month() , rxTime.cap(1).toUInt()), QTime( rxTime.cap(2).toUInt() , rxTime.cap(3).toUInt() , rxTime.cap(5).toUInt() ) );
 					}
 
-					Kopete::Message msg(timestamp, from, to, msgElem.text(), dir);
+					Kopete::Message msg(from, to);
+					msg.setTimestamp( timestamp );
+					msg.setDirection( dir );
+					msg.setPlainBody( msgElem.text() );
 					if (colorize)
 					{
-						msg.setBody( QString::fromLatin1("<span style=\"color:%1\" title=\"%2\">%3</span>")
-							.arg( fgColor.name(), timestamp.toString(Qt::LocalDate), msg.escapedBody() ),
-							Kopete::Message::RichText
-						);
-						msg.setFg( fgColor );
+						msg.setHtmlBody( QString::fromLatin1("<span style=\"color:%1\" title=\"%2\">%3</span>")
+							.arg( fgColor.name(), timestamp.toString(Qt::LocalDate), msg.escapedBody() ));
+						msg.setForegroundColor( fgColor );
+						msg.addClass( "history" );
 					}
 					else
 					{
-						msg.setBody( QString::fromLatin1("<span title=\"%1\">%2</span>")
-							.arg( timestamp.toString(Qt::LocalDate), msg.escapedBody() ),
-							Kopete::Message::RichText
-						);
+						msg.setHtmlBody( QString::fromLatin1("<span title=\"%1\">%2</span>")
+							.arg( timestamp.toString(Qt::LocalDate), msg.escapedBody() ));
 					}
 
 					if(reverseOrder)
@@ -633,7 +646,7 @@ QValueList<Kopete::Message> HistoryLogger::readMessages(unsigned int lines,
 							// In case of hideoutgoing messages, it is faster to do
 							// this, so we don't parse the date if it is not needed
 							QRegExp rx("(\\d+) (\\d+):(\\d+):(\\d+)");
-							rx.search(msgElem.attribute("time"));
+							rx.indexIn(msgElem.attribute("time"));
 
 							QDate d = QDate::currentDate().addMonths(0-m_currentMonth);
 							timestamp = QDateTime(
@@ -670,7 +683,7 @@ QString HistoryLogger::getFileName(const Kopete::Contact* c, QDate date)
 	c->contactId().replace( QRegExp( QString::fromLatin1( "[./~?*]" ) ), QString::fromLatin1( "-" ) ) +
 		date.toString(".yyyyMM");
 
-	QString filename=locateLocal( "data", QString::fromLatin1( "kopete/logs/" ) + name+ QString::fromLatin1( ".xml" ) ) ;
+	QString filename=KStandardDirs::locateLocal( "data", QString::fromLatin1( "kopete/logs/" ) + name+ QString::fromLatin1( ".xml" ) ) ;
 
 	//Check if there is a kopete 0.7.x file
 	QFileInfo fi(filename);
@@ -681,7 +694,7 @@ QString HistoryLogger::getFileName(const Kopete::Contact* c, QDate date)
 			c->contactId().replace( QRegExp( QString::fromLatin1( "[./~?*]" ) ), QString::fromLatin1( "-" ) ) +
 			date.toString(".yyyyMM");
 
-		QString filename2=locateLocal( "data", QString::fromLatin1( "kopete/logs/" ) + name+ QString::fromLatin1( ".xml" ) ) ;
+		QString filename2=KStandardDirs::locateLocal( "data", QString::fromLatin1( "kopete/logs/" ) + name+ QString::fromLatin1( ".xml" ) ) ;
 
 		QFileInfo fi2(filename2);
 		if(fi2.exists())
@@ -698,38 +711,36 @@ unsigned int HistoryLogger::getFirstMonth(const Kopete::Contact *c)
 		return getFirstMonth();
 
 	QRegExp rx( "\\.(\\d\\d\\d\\d)(\\d\\d)" );
-	QFileInfo *fi;
+	QFileInfo fi;
 
 	// BEGIN check if there are Kopete 0.7.x
-	QDir d1(locateLocal("data",QString("kopete/logs/")+
+	QDir d1(KStandardDirs::locateLocal("data",QString("kopete/logs/")+
 		c->protocol()->pluginId().replace( QRegExp(QString::fromLatin1("[./~?*]")),QString::fromLatin1("-"))
 		));
 	d1.setFilter( QDir::Files | QDir::NoSymLinks );
 	d1.setSorting( QDir::Name );
 
-	const QFileInfoList *list1 = d1.entryInfoList();
-	QFileInfoListIterator it1( *list1 );
+	const QFileInfoList list1 = d1.entryInfoList();
 
-	while ( (fi = it1.current()) != 0 )
+	foreach(fi, list1)
 	{
-		if(fi->fileName().contains(c->contactId().replace( QRegExp( QString::fromLatin1( "[./~?*]" ) ), QString::fromLatin1( "-" ) )))
+		if(fi.fileName().contains(c->contactId().replace( QRegExp( QString::fromLatin1( "[./~?*]" ) ), QString::fromLatin1( "-" ) )))
 		{
-			rx.search(fi->fileName());
+			rx.indexIn(fi.fileName());
 			int result = 12*(QDate::currentDate().year() - rx.cap(1).toUInt()) +QDate::currentDate().month() - rx.cap(2).toUInt();
 
 			if(result < 0)
 			{
-				kdWarning(14310) << k_funcinfo << "Kopete only found log file from Kopete 0.7.x made in the future. Check your date!" << endl;
+				kWarning(14310) << "Kopete only found log file from Kopete 0.7.x made in the future. Check your date!";
 				break;
 			}
 			return result;
 		}
-		++it1;
 	}
 	// END of kopete 0.7.x check
 
 
-	QDir d(locateLocal("data",QString("kopete/logs/")+
+	QDir d(KStandardDirs::locateLocal("data",QString("kopete/logs/")+
 		c->protocol()->pluginId().replace( QRegExp(QString::fromLatin1("[./~?*]")),QString::fromLatin1("-")) +
 		QString::fromLatin1( "/" ) +
 		c->account()->accountId().replace( QRegExp( QString::fromLatin1( "[./~?*]" ) ), QString::fromLatin1( "-" ) )
@@ -738,22 +749,21 @@ unsigned int HistoryLogger::getFirstMonth(const Kopete::Contact *c)
 	d.setFilter( QDir::Files | QDir::NoSymLinks );
 	d.setSorting( QDir::Name );
 
-	const QFileInfoList *list = d.entryInfoList();
-	QFileInfoListIterator it( *list );
-	while ( (fi = it.current()) != 0 )
+	const QFileInfoList list = d.entryInfoList();
+
+	foreach(fi, list)
 	{
-		if(fi->fileName().contains(c->contactId().replace( QRegExp( QString::fromLatin1( "[./~?*]" ) ), QString::fromLatin1( "-" ) )))
+		if(fi.fileName().contains(c->contactId().replace( QRegExp( QString::fromLatin1( "[./~?*]" ) ), QString::fromLatin1( "-" ) )))
 		{
-			rx.search(fi->fileName());
+			rx.indexIn(fi.fileName());
 			int result = 12*(QDate::currentDate().year() - rx.cap(1).toUInt()) +QDate::currentDate().month() - rx.cap(2).toUInt();
 			if(result < 0)
 			{
-				kdWarning(14310) << k_funcinfo << "Kopete only found log file made in the future. Check your date!" << endl;
+				kWarning(14310) << "Kopete only found log file made in the future. Check your date!";
 				break;
 			}
 			return result;
 		}
-		++it;
 	}
 	return 0;
 }
@@ -767,11 +777,11 @@ unsigned int HistoryLogger::getFirstMonth()
 		return 0;
 
 	int m=0;
-	QPtrList<Kopete::Contact> contacts=m_metaContact->contacts();
-	QPtrListIterator<Kopete::Contact> it( contacts );
-	for( ; it.current(); ++it )
+	QList<Kopete::Contact*> contacts=m_metaContact->contacts();
+
+	foreach(Kopete::Contact* contact, contacts)
 	{
-		int m2=getFirstMonth(*it);
+		int m2=getFirstMonth(contact);
 		if(m2>m) m=m2;
 	}
 	m_cachedMonth=m;
@@ -791,7 +801,7 @@ void HistoryLogger::slotMCDeleted()
 void HistoryLogger::setFilter(const QString& filter, bool caseSensitive , bool isRegExp)
 {
 	m_filter=filter;
-	m_filterCaseSensitive=caseSensitive;
+	m_filterCaseSensitive=caseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive;
 	m_filterRegExp=isRegExp;
 }
 
@@ -802,7 +812,7 @@ QString HistoryLogger::filter() const
 
 bool HistoryLogger::filterCaseSensitive() const
 {
-	return m_filterCaseSensitive;
+	return (m_filterCaseSensitive == Qt::CaseSensitive);
 }
 
 bool HistoryLogger::filterRegExp() const
@@ -810,35 +820,34 @@ bool HistoryLogger::filterRegExp() const
 	return m_filterRegExp;
 }
 
-QValueList<int> HistoryLogger::getDaysForMonth(QDate date)
+QList<int> HistoryLogger::getDaysForMonth(QDate date)
 {
 	QRegExp rxTime("time=\"(\\d+) \\d+:\\d+(:\\d+)?\""); //(with a 0.7.x compatibility)
 
-	QValueList<int> dayList;
+	QList<int> dayList;
 
-	QPtrList<Kopete::Contact> contacts = m_metaContact->contacts();
-	QPtrListIterator<Kopete::Contact> it(contacts);
+	QList<Kopete::Contact*> contacts = m_metaContact->contacts();
 
 	int lastDay=0;
-	for(; it.current(); ++it)
+	foreach(Kopete::Contact *contact, contacts)
 	{
-//		kdDebug() << getFileName(*it, date) << endl;
-		QFile file(getFileName(*it, date));
-		if(!file.open(IO_ReadOnly))
+//		kDebug() << getFileName(*it, date);
+		QFile file(getFileName(contact, date));
+		if(!file.open(QIODevice::ReadOnly))
 		{
 			continue;
 		}
 		QTextStream stream(&file);
-		QString fullText = stream.read();
+		QString fullText = stream.readAll();
 		file.close();
 
 		int pos = 0;
-		while( (pos = rxTime.search(fullText, pos)) != -1)
+		while( (pos = rxTime.indexIn(fullText, pos)) != -1)
 		{
 			pos += rxTime.matchedLength();
 			int day=rxTime.capturedTexts()[1].toInt();
 			
-			if ( day !=lastDay && dayList.find(day) == dayList.end()) // avoid duplicates
+			if ( day !=lastDay && dayList.indexOf(day) == -1) // avoid duplicates
 			{
 				dayList.append(rxTime.capturedTexts()[1].toInt());
 				lastDay=day;
