@@ -18,9 +18,9 @@
 #ifndef HISTORYPLUGIN_H
 #define HISTORYPLUGIN_H
 
-#include <qobject.h>
-#include <qmap.h>
-#include <qstring.h>
+#include <QObject>
+#include <QMap>
+
 
 #include "kopeteplugin.h"
 
@@ -28,15 +28,12 @@
 #include "kopetemessagehandler.h"
 
 class KopeteView;
-class KActionCollection;
 
 namespace Kopete
 {
-class MetaContact;
 class ChatSession;
 }
 
-class HistoryPreferences;
 class HistoryGUIClient;
 class HistoryPlugin;
 
@@ -55,7 +52,7 @@ class HistoryMessageLoggerFactory : public Kopete::MessageHandlerFactory
 {
 	HistoryPlugin *history;
 public:
-	HistoryMessageLoggerFactory( HistoryPlugin *history ) : history(history) {}
+	explicit HistoryMessageLoggerFactory( HistoryPlugin *history ) : history(history) {}
 	Kopete::MessageHandler *create( Kopete::ChatSession * /*manager*/, Kopete::Message::MessageDirection direction )
 	{
 		if( direction != Kopete::Message::Inbound )
@@ -75,7 +72,7 @@ class HistoryPlugin : public Kopete::Plugin
 {
 	Q_OBJECT
 	public:
-		HistoryPlugin( QObject *parent, const char *name, const QStringList &args );
+		HistoryPlugin( QObject *parent, const QStringList &args );
 		~HistoryPlugin();
 
 		/**
