@@ -4,7 +4,7 @@
     Kopete Now Listening To plugin
 
     Copyright (c) 2002,2003,2004 by Will Stephenson <will@stevello.free-online.co.uk>
-    Copyright (c) 2005           by Michaël Larouche <michael.larouche@kdemail.net>
+    Copyright (c) 2005           by Michaël Larouche <larouche@kde.org>
 
     Kopete    (c) 2002-2005      by the Kopete developers  <kopete-devel@kde.org>
 
@@ -21,39 +21,45 @@
 #include <qlineedit.h>
 #include <qlayout.h>
 #include <qradiobutton.h>
+//Added by qt3to4:
+#include <QVBoxLayout>
 
-#include <klistbox.h>
+#include <k3listbox.h>
 #include <klocale.h>
-#include <kgenericfactory.h>
+#include <kpluginfactory.h>
 
-#include "config.h" // for HAVE_XMMS
-#include "nowlisteningprefs.h"
+#include "config-kopete.h" // for HAVE_XMMS
+#include "ui_nowlisteningprefs.h"
 #include "nowlisteningconfig.h"
 #include "nowlisteningpreferences.h"
 #include "nowlisteningpreferences.moc"
 
-typedef KGenericFactory<NowListeningPreferences> NowListeningPreferencesFactory;
-K_EXPORT_COMPONENT_FACTORY( kcm_kopete_nowlistening, NowListeningPreferencesFactory( "kcm_kopete_nowlistening" )  )
+K_PLUGIN_FACTORY( NowListeningPreferencesFactory, registerPlugin<NowListeningPreferences>(); )
+K_EXPORT_PLUGIN( NowListeningPreferencesFactory( "kcm_kopete_nowlistening" ) )
 
 
-NowListeningPreferences::NowListeningPreferences(QWidget *parent, const char* /*name*/, const QStringList &args)
-	: KCModule( NowListeningPreferencesFactory::instance(), parent, args )
+NowListeningPreferences::NowListeningPreferences(QWidget *parent, const QVariantList &args)
+	: KCModule( NowListeningPreferencesFactory::componentData(), parent, args )
 {
-	(  new QVBoxLayout(  this ) )->setAutoAdd(  true );
-	preferencesDialog = new NowListeningPrefsUI( this );
+	QVBoxLayout* l = new QVBoxLayout( this );
+	QWidget* w = new QWidget;
+	preferencesDialog = new Ui::NowListeningPrefsUI;
+	preferencesDialog->setupUi( w );
+	l->addWidget( w );
 
-	addConfig( NowListeningConfig::self(), preferencesDialog );
+	//Is this correct?
+	addConfig( NowListeningConfig::self(), w );
 
 	// Fill the media player listbox.
 	preferencesDialog->kcfg_SelectedMediaPlayer->insertItem(QString::fromUtf8("Kscd"));
 	preferencesDialog->kcfg_SelectedMediaPlayer->insertItem(QString::fromUtf8("Noatun"));
 	preferencesDialog->kcfg_SelectedMediaPlayer->insertItem(QString::fromUtf8("Juk"));
-	preferencesDialog->kcfg_SelectedMediaPlayer->insertItem(QString::fromUtf8("amaroK"));
+	preferencesDialog->kcfg_SelectedMediaPlayer->insertItem(QString::fromUtf8("Amarok"));
 	preferencesDialog->kcfg_SelectedMediaPlayer->insertItem(QString::fromUtf8("Kaffeine"));
+	preferencesDialog->kcfg_SelectedMediaPlayer->insertItem(QString::fromUtf8("Quod Libet"));
 #if defined Q_WS_X11 && !defined K_WS_QTONLY && defined HAVE_XMMS
 	preferencesDialog->kcfg_SelectedMediaPlayer->insertItem(QString::fromUtf8("XMMS"));
 #endif
-	load();
 }
 
 NowListeningPreferences::~NowListeningPreferences( )
