@@ -1,7 +1,8 @@
 /*
     Kopete GroupWise Protocol
-    gweditaccountwidget.h- widget for adding GroupWise contacts
+    gwaddcontactpage.h- widget for adding GroupWise contacts
 
+    Copyright (c) 2006      Novell, Inc	 	 	 http://www.opensuse.org
     Copyright (c) 2004      SUSE Linux AG	 	 http://www.suse.com
     
     Based on Testbed   
@@ -19,12 +20,15 @@
     *************************************************************************
 */
 
-#ifndef TESTBEDADDCONTACTPAGE_H
-#define TESTBEDADDCONTACTPAGE_H
+#ifndef GWADDCONTACTPAGE_H
+#define GWADDCONTACTPAGE_H
 
 #include "gwerror.h"
 
 #include <addcontactpage.h>
+//Added by qt3to4:
+#include <QLabel>
+#include <Q3ValueList>
 
 class QLabel;
 namespace Kopete { class Account; }
@@ -42,7 +46,7 @@ class GroupWiseAddContactPage : public AddContactPage
 {
 	Q_OBJECT
 public:
-    GroupWiseAddContactPage( Kopete::Account * owner, QWidget* parent = 0, const char* name = 0 );
+    explicit GroupWiseAddContactPage( Kopete::Account * owner, QWidget* parent = 0 );
     ~GroupWiseAddContactPage();
 	
     /**
@@ -54,7 +58,7 @@ public:
 	 */
     virtual bool validateData();
 protected:
-	QValueList< GroupWise::ContactDetails > m_searchResults;
+	Q3ValueList< GroupWise::ContactDetails > m_searchResults;
 	unsigned char searchOperation( int comboIndex );
 	GroupWiseAccount * m_account;
 	GroupWiseAddUI * m_gwAddUI;
@@ -65,4 +69,4 @@ protected:
 	bool m_canadd;
 };
 
-#endif
+#endif // GWADDCONTACTPAGE_H
