@@ -29,6 +29,7 @@
 
 #include <kopetegroup.h>
 #include <kopetecontactlist.h>
+#include <kopeteavatarmanager.h>
 
 #include "jabberbasecontact.h"
 
@@ -90,7 +91,7 @@ bool JabberBaseContact::isReachable ()
 
 void JabberBaseContact::updateContact ( const XMPP::RosterItem & item )
 {
-	kdDebug ( JABBER_DEBUG_GLOBAL ) << k_funcinfo << "Synchronizing local copy of " << contactId() << " with information received from server.  (name='" << item.name() << "' groups='" << item.groups() << "')"<< endl;
+	kDebug ( JABBER_DEBUG_GLOBAL ) << "Synchronizing local copy of " << contactId() << " with information received from server.  (name='" << item.name() << "' groups='" << item.groups() << "')";
 
 	mRosterItem = item;
 
@@ -110,16 +111,11 @@ void JabberBaseContact::updateContact ( const XMPP::RosterItem & item )
 	if( metaContact() != Kopete::ContactList::self()->myself() )
 	{
 		// only update the alias if its not empty
-		if ( !item.name().isEmpty () && item.name() != item.jid().bare() )
+		if ( !item.name().isEmpty () && item.name() != item.jid().bare() 
+			&& metaContact()->customDisplayName() != item.name () )
 		{
-			QString newName = item.name ();
-			QString oldName = metaContact()->displayName();
-			Kopete::Contact *source=metaContact()->displayNameSourceContact();
-//			kdDebug ( JABBER_DEBUG_GLOBAL ) << k_funcinfo << "setting display name of " << contactId () << " to " << newName << endl;
-			metaContact()->setDisplayName ( newName );
-			//automatically set  to custom source if the source is to this contact.
-			if( metaContact()->displayNameSource()==Kopete::MetaContact::SourceContact && newName != oldName && ( source == this || source == 0L  ) )
-				metaContact()->setDisplayNameSource( Kopete::MetaContact::SourceCustom );
+			kDebug ( JABBER_DEBUG_GLOBAL ) << "setting display name of " << contactId () << " to " << item.name();
+			metaContact()->setDisplayName ( item.name () );
 		}
 	}
 
@@ -134,11 +130,11 @@ void JabberBaseContact::updateContact ( const XMPP::RosterItem & item )
 			break;
 		case XMPP::Subscription::To:
 			setProperty ( protocol()->propSubscriptionStatus,
-						  i18n ( "You can see this contact's status but they cannot see your status." ) );
+						  i18n ( "You can see this contact's status, but he/she cannot see your status." ) );
 			break;
 		case XMPP::Subscription::From:
 			setProperty ( protocol()->propSubscriptionStatus,
-						  i18n ( "This contact can see your status but you cannot see their status." ) );
+						  i18n ( "This contact can see your status, but you cannot see his/her status." ) );
 			break;
 		case XMPP::Subscription::Both:
 			setProperty ( protocol()->propSubscriptionStatus,
@@ -162,19 +158,19 @@ void JabberBaseContact::updateContact ( const XMPP::RosterItem & item )
 		Kopete::GroupList groupsToRemoveFrom, groupsToAddTo;
 	
 		// find all groups our contact is in but that are not in the server side roster
-		for ( unsigned i = 0; i < metaContact()->groups().count (); i++ )
+		for ( int i = 0; i < metaContact()->groups().count (); i++ )
 		{
-			if ( item.groups().find ( metaContact()->groups().at(i)->displayName () ) == item.groups().end () )
+			if ( !item.groups().contains ( metaContact()->groups().at(i)->displayName () ) )
 				groupsToRemoveFrom.append ( metaContact()->groups().at ( i ) );
 		}
 	
 		// now find all groups that are in the server side roster but not in the local group
-		for ( unsigned i = 0; i < item.groups().count (); i++ )
+		for ( int i = 0; i < item.groups().count (); i++ )
 		{
 			bool found = false;
-			for ( unsigned j = 0; j < metaContact()->groups().count (); j++)
+			for ( int j = 0; j < metaContact()->groups().count (); j++)
 			{
-				if ( metaContact()->groups().at(j)->displayName () == *item.groups().at(i) )
+				if ( metaContact()->groups().at(j)->displayName () == item.groups().at(i) )
 				{
 					found = true;
 					break;
@@ -183,7 +179,7 @@ void JabberBaseContact::updateContact ( const XMPP::RosterItem & item )
 			
 			if ( !found )
 			{
-				groupsToAddTo.append ( Kopete::ContactList::self()->findGroup ( *item.groups().at(i) ) );
+				groupsToAddTo.append ( Kopete::ContactList::self()->findGroup ( item.groups().at(i) ) );
 			}
 		}
 	
@@ -195,18 +191,18 @@ void JabberBaseContact::updateContact ( const XMPP::RosterItem & item )
 		*/
 		if ( ( groupsToAddTo.count () == 0 ) && ( groupsToRemoveFrom.contains ( Kopete::Group::topLevel () ) ) )
 		{
-			groupsToRemoveFrom.remove ( Kopete::Group::topLevel () );
+			groupsToRemoveFrom.removeAll ( Kopete::Group::topLevel () );
 		}
 	
-		for ( Kopete::Group *group = groupsToRemoveFrom.first (); group; group = groupsToRemoveFrom.next () )
+		foreach ( Kopete::Group *group, groupsToRemoveFrom )
 		{
-			kdDebug ( JABBER_DEBUG_GLOBAL ) << k_funcinfo << "Removing " << contactId() << " from group " << group->displayName () << endl;
+			kDebug ( JABBER_DEBUG_GLOBAL ) << "Removing " << contactId() << " from group " << group->displayName ();
 			metaContact()->removeFromGroup ( group );
 		}
 	
-		for ( Kopete::Group *group = groupsToAddTo.first (); group; group = groupsToAddTo.next () )
+		foreach ( Kopete::Group *group, groupsToAddTo )
 		{
-			kdDebug ( JABBER_DEBUG_GLOBAL ) << k_funcinfo << "Adding " << contactId() << " to group " << group->displayName () << endl;
+			kDebug ( JABBER_DEBUG_GLOBAL ) << "Adding " << contactId() << " to group " << group->displayName ();
 			metaContact()->addToGroup ( group );
 		}
 	}
@@ -277,10 +273,10 @@ void JabberBaseContact::updateResourceList ()
 		
 		// resource timestamp
 		resourceListStr += QString ( "<tr><td>%1: %2</td></tr>" ).
-						   arg ( i18n ( "Timestamp" ), KGlobal::locale()->formatDateTime ( (*it)->resource().status().timeStamp(), true, true ) );
+						   arg ( i18n ( "Timestamp" ), KGlobal::locale()->formatDateTime ( (*it)->resource().status().timeStamp(), KLocale::ShortDate, true ) );
 
 		// message, if any
-		if ( !(*it)->resource().status().status().stripWhiteSpace().isEmpty () )
+		if ( !(*it)->resource().status().status().trimmed().isEmpty () )
 		{
 			resourceListStr += QString ( "<tr><td>%1: %2</td></tr>" ).
 							   arg ( 
@@ -297,7 +293,7 @@ void JabberBaseContact::updateResourceList ()
 
 void JabberBaseContact::reevaluateStatus ()
 {
-	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "Determining new status for " << contactId () << endl;
+	kDebug (JABBER_DEBUG_GLOBAL) << "Determining new status for " << contactId ();
 
 	Kopete::OnlineStatus status;
 	XMPP::Resource resource = account()->resourcePool()->bestResource ( mRosterItem.jid () );
@@ -320,21 +316,14 @@ void JabberBaseContact::reevaluateStatus ()
 
 	updateResourceList ();
 
-	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "New status for " << contactId () << " is " << status.description () << endl;
+	kDebug (JABBER_DEBUG_GLOBAL) << "New status for " << contactId () << " is " << status.description ();
 	setOnlineStatus ( status );
 
 	/*
 	 * Set away message property.
 	 * We just need to read it from the current resource.
 	 */
-	if ( !resource.status ().status ().isEmpty () )
-	{
-		setProperty ( protocol()->propAwayMessage, resource.status().status () );
-	}
-	else
-	{
-		removeProperty ( protocol()->propAwayMessage );
-	}
+	setStatusMessage( resource.status().status() );
 
 }
 
@@ -409,7 +398,7 @@ void JabberBaseContact::slotUserInfo( )
 
 void JabberBaseContact::setPropertiesFromVCard ( const XMPP::VCard &vCard )
 {
-	kdDebug ( JABBER_DEBUG_GLOBAL ) << k_funcinfo << "Updating vCard for " << contactId () << endl;
+	kDebug ( JABBER_DEBUG_GLOBAL ) << "Updating vCard for " << contactId ();
 
 	// update vCard cache timestamp if this is not a temporary contact
 	if ( metaContact() && !metaContact()->isTemporary () )
@@ -428,6 +417,10 @@ void JabberBaseContact::setPropertiesFromVCard ( const XMPP::VCard &vCard )
 		{
 			setProperty ( protocol()->propNickName, vCard.nickName () );
 		}
+		else if ( !vCard.fullName().isEmpty () ) // google talk contacts for example do not have a nickname; better show fullname instead of jabber id
+		{
+			setProperty ( protocol()->propNickName, vCard.fullName () );
+		}
 		else
 		{
 			removeProperty ( protocol()->propNickName );
@@ -450,7 +443,7 @@ void JabberBaseContact::setPropertiesFromVCard ( const XMPP::VCard &vCard )
 	if ( !vCard.fullName().isEmpty () && vCard.givenName().isEmpty () && vCard.familyName().isEmpty () )
 	{
 		QString lastName = vCard.fullName().section ( ' ', 0, -1 );
-		QString firstName = vCard.fullName().left(vCard.fullName().length () - lastName.length ()).stripWhiteSpace ();
+		QString firstName = vCard.fullName().left(vCard.fullName().length () - lastName.length ()).trimmed ();
 
 		setProperty ( protocol()->propFirstName, firstName );
 		setProperty ( protocol()->propLastName, lastName );
@@ -629,16 +622,14 @@ void JabberBaseContact::setPropertiesFromVCard ( const XMPP::VCard &vCard )
 	removeProperty( protocol()->propPhoto );
 
 	QImage contactPhoto;
-	QString fullJid =  mRosterItem.jid().full();
-	QString finalPhotoPath = locateLocal("appdata", "jabberphotos/" + fullJid.replace(QRegExp("[./~]"),"-")  +".png");
 	
 	// photo() is a QByteArray
 	if ( !vCard.photo().isEmpty() )
 	{
-		kdDebug( JABBER_DEBUG_GLOBAL ) << k_funcinfo << "Contact has a photo embedded into his vCard." << endl;
+		kDebug( JABBER_DEBUG_GLOBAL ) << "Contact has a photo embedded into his vCard.";
 
 		// QImage is used to save to disk in PNG later.
-		contactPhoto = QImage( vCard.photo() );
+		contactPhoto = QImage::fromData( vCard.photo() );
 	}
 	// Contact photo is a URI.
 	else if( !vCard.photoURI().isEmpty() )
@@ -652,18 +643,30 @@ void JabberBaseContact::setPropertiesFromVCard ( const XMPP::VCard &vCard )
 			return;
 		}
 
-		kdDebug( JABBER_DEBUG_GLOBAL ) << k_funcinfo << "Contact photo is a URI." << endl;
+
+		kDebug( JABBER_DEBUG_GLOBAL ) << "Contact photo is a URI.";
 
 		contactPhoto = QImage( tempPhotoPath );
 		
 		KIO::NetAccess::removeTempFile(  tempPhotoPath );
 	}
 
-	// Save the image to the disk, then set the property.
-	if( !contactPhoto.isNull() && contactPhoto.save(finalPhotoPath, "PNG") )
+	if ( !contactId().isEmpty() )
 	{
-		kdDebug( JABBER_DEBUG_GLOBAL ) << k_funcinfo << "Setting photo for contact: " << fullJid << endl;
-		setProperty( protocol()->propPhoto, finalPhotoPath );
+		// add the entry using the avatar manager
+		Kopete::AvatarManager::AvatarEntry entry;
+		entry.name = contactId();
+		entry.image = contactPhoto;
+		entry.category = Kopete::AvatarManager::Contact;
+		entry.contact = this;	
+		entry = Kopete::AvatarManager::self()->add(entry);
+
+		// Save the image to the disk, then set the property.
+		if(!entry.path.isNull())
+		{
+			kDebug( JABBER_DEBUG_GLOBAL ) << "Setting photo for contact: " << contactId();
+			setProperty( protocol()->propPhoto, entry.path );
+		}
 	}
 
 }
