@@ -4,7 +4,7 @@
                              -------------------
     begin                : Mon Dec 9 2002
     copyright            : (C) 2002-2003 by Till Gerken <till@tantalo.net>
-                           Based on code by Olivier Goffart <ogoffart @ kde.org>
+                           Based on code by Olivier Goffart <ogoffart@kde.org>
     email                : kopete-devel@kde.org
  ***************************************************************************/
 
@@ -22,15 +22,17 @@
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qspinbox.h>
-#include <qcombobox.h>
+#include <q3combobox.h>
 #include <qlabel.h>
 
 #include <kconfig.h>
 #include <kmessagebox.h>
 #include <klocale.h>
-#include <kpassdlg.h>
+#include <kglobal.h>
+#include <klineedit.h>
 #include <kopetepassword.h>
 #include <kopetepasswordedaccount.h>
+#include "kopetecontact.h"
 
 #include "kopeteuiglobal.h"
 #include "kopetepasswordwidget.h"
@@ -39,10 +41,12 @@
 #include "jabbereditaccountwidget.h"
 #include "jabberregisteraccount.h"
 #include "dlgjabberchangepassword.h"
+#include "privacydlg.h"
 
-JabberEditAccountWidget::JabberEditAccountWidget (JabberProtocol * proto, JabberAccount * ident, QWidget * parent, const char *name)
-						: DlgJabberEditAccountWidget (parent, name), KopeteEditAccountWidget (ident)
+JabberEditAccountWidget::JabberEditAccountWidget (JabberProtocol * proto, JabberAccount * ident, QWidget * parent)
+						: QWidget(parent), DlgJabberEditAccountWidget(), KopeteEditAccountWidget (ident)
 {
+	setupUi(this);
 
 	m_protocol = proto;
 
@@ -52,18 +56,29 @@ JabberEditAccountWidget::JabberEditAccountWidget (JabberProtocol * proto, Jabber
 	connect (cbUseSSL, SIGNAL (toggled (bool)), this, SLOT (sslToggled (bool)));
 
 	connect (btnChangePassword, SIGNAL ( clicked() ), this, SLOT ( slotChangePasswordClicked () ));
+	
+	connect (privacyListsButton, SIGNAL ( clicked() ), this, SLOT ( slotPrivacyListsClicked() ) );
 
 	if (account())
 	{
 		// we are working with an existing account
 		reopen ();
+		registrationGroupBox->hide();
 		btnRegister->setEnabled ( false );
+		
+		if ( account()->myself()->isOnline() )
+			privacyListsButton->setEnabled (true);
+		else
+			privacyListsButton->setEnabled (false);
 	}
 	else
 	{
 		// this is a new account
+		changePasswordGroupBox->hide();
 		btnChangePassword->setEnabled ( false );
 		connect (btnRegister, SIGNAL (clicked ()), this, SLOT (registerClicked ()));
+		
+		privacyListsButton->setEnabled (false);
 	}
 }
 
@@ -82,26 +97,29 @@ void JabberEditAccountWidget::reopen ()
 {
 
 	// FIXME: this is temporary until Kopete supports accound ID changes!
-	mID->setDisabled(true);
+	mID->setReadOnly(true);
 
 	mID->setText (account()->accountId ());
 	mPass->load (&account()->password ());
+	cbAutoConnect->setChecked (account()->excludeConnect());
 	
 	mResource->setText (account()->configGroup()->readEntry ("Resource", QString::fromLatin1("Kopete")));
-	mPriority->setValue (account()->configGroup()->readNumEntry ("Priority", 5));
-	mServer->setText (account()->configGroup()->readEntry ("Server", QString::null));
+	mPriority->setValue (account()->configGroup()->readEntry ("Priority", 5));
+	mServer->setText (account()->configGroup()->readEntry ("Server", QString()));
 
-	cbUseSSL->setChecked (account()->configGroup()->readBoolEntry( "UseSSL", false));
+	cbUseSSL->setChecked (account()->configGroup()->readEntry( "UseSSL", false));
 
-	mPort->setValue (account()->configGroup()->readNumEntry("Port", 5222));
+	mPort->setValue (account()->configGroup()->readEntry("Port", 5222));
 
-	QString auth = account()->configGroup()->readEntry("AuthType", QString::null);
+	QString auth = account()->configGroup()->readEntry("AuthType", QString());
 
-	cbCustomServer->setChecked (account()->configGroup()->readBoolEntry("CustomServer",false));
+	cbCustomServer->setChecked (account()->configGroup()->readEntry("CustomServer",false));
 
 	if(cbCustomServer->isChecked ())
 	{
+		labelServer->setEnabled(true);
 		mServer->setEnabled(true);
+		labelPort->setEnabled(true);
 		mPort->setEnabled(true);
 	}
 	else
@@ -110,26 +128,27 @@ void JabberEditAccountWidget::reopen ()
 		mServer->setText(mID->text().section("@", 1));
 	}
 
-	cbAllowPlainTextPassword->setChecked (account()->configGroup()->readBoolEntry("AllowPlainTextPassword", true));
+	cbAllowPlainTextPassword->setChecked (account()->configGroup()->readEntry("AllowPlainTextPassword", true));
 
-	KGlobal::config()->setGroup("Jabber");
-	leLocalIP->setText (KGlobal::config()->readEntry("LocalIP", ""));
-	sbLocalPort->setValue (KGlobal::config()->readNumEntry("LocalPort", 8010));
+	KConfigGroup config = KGlobal::config()->group("Jabber");
+	leLocalIP->setText (config.readEntry("LocalIP", QString()));
+	sbLocalPort->setValue (config.readEntry("LocalPort", 8010));
 
-	leProxyJID->setText (account()->configGroup()->readEntry("ProxyJID", QString::null));
+	leProxyJID->setText (account()->configGroup()->readEntry("ProxyJID", QString()));
 
 	// Privacy
-	cbSendEvents->setChecked( account()->configGroup()->readBoolEntry("SendEvents", true) );
-	cbSendDeliveredEvent->setChecked( account()->configGroup()->readBoolEntry("SendDeliveredEvent", true) );
-	cbSendDisplayedEvent->setChecked( account()->configGroup()->readBoolEntry("SendDisplayedEvent", true) );
-	cbSendComposingEvent->setChecked( account()->configGroup()->readBoolEntry("SendComposingEvent", true) );
+	cbSendEvents->setChecked( account()->configGroup()->readEntry("SendEvents", true) );
+	cbSendDeliveredEvent->setChecked( account()->configGroup()->readEntry("SendDeliveredEvent", true) );
+	cbSendDisplayedEvent->setChecked( account()->configGroup()->readEntry("SendDisplayedEvent", true) );
+	cbSendComposingEvent->setChecked( account()->configGroup()->readEntry("SendComposingEvent", true) );
+	cbSendGoneEvent->setChecked( account()->configGroup()->readEntry("SendGoneEvent", true) );
 
-	cbHideSystemInfo->setChecked( account()->configGroup()->readBoolEntry("HideSystemInfo", false) );
+	cbHideSystemInfo->setChecked( account()->configGroup()->readEntry("HideSystemInfo", false) );
 }
 
 Kopete::Account *JabberEditAccountWidget::apply ()
 {
-	kdDebug ( JABBER_DEBUG_GLOBAL ) << "JabberEditAccount::apply()" << endl;
+	kDebug ( JABBER_DEBUG_GLOBAL ) << "JabberEditAccount::apply()";
 
 	if (!account())
 	{
@@ -138,7 +157,7 @@ Kopete::Account *JabberEditAccountWidget::apply ()
 
 	if(account()->isConnected())
 	{
-		KMessageBox::information(this,
+		KMessageBox::queuedMessageBox(this, KMessageBox::Information,
 					i18n("The changes you just made will take effect next time you log in with Jabber."),
 					i18n("Jabber Changes During Online Jabber Session"));
 	}
@@ -171,9 +190,10 @@ void JabberEditAccountWidget::writeConfig ()
 
 	account()->setExcludeConnect(cbAutoConnect->isChecked());
 
-	KGlobal::config()->setGroup("Jabber");
-	KGlobal::config()->writeEntry("LocalIP", leLocalIP->text());
-	KGlobal::config()->writeEntry("LocalPort", sbLocalPort->value());
+	KConfigGroup config = KGlobal::config()->group("Jabber");
+	
+	config.writeEntry("LocalIP", leLocalIP->text());
+	config.writeEntry("LocalPort", sbLocalPort->value());
 
 	account()->configGroup()->writeEntry("ProxyJID", leProxyJID->text());
 
@@ -182,9 +202,9 @@ void JabberEditAccountWidget::writeConfig ()
 	account()->configGroup()->writeEntry("SendDeliveredEvent", cbSendDeliveredEvent->isChecked());
 	account()->configGroup()->writeEntry("SendDisplayedEvent", cbSendDisplayedEvent->isChecked());
 	account()->configGroup()->writeEntry("SendComposingEvent", cbSendComposingEvent->isChecked());
+	account()->configGroup()->writeEntry("SendGoneEvent", cbSendGoneEvent->isChecked());
 	
 	account()->configGroup()->writeEntry("HideSystemInfo", cbHideSystemInfo->isChecked());
-
 }
 
 bool JabberEditAccountWidget::validateData ()
@@ -212,12 +232,16 @@ void JabberEditAccountWidget::updateServerField ()
 		// check if ssl is enabled and set the port correctly
 		sslToggled(cbUseSSL->isChecked());
 		mServer->setText(newServer);
+		labelServer->setEnabled(false);
 		mServer->setEnabled(false);
+		labelPort->setEnabled(false);
 		mPort->setEnabled(false);
 	}
 	else
 	{
+		labelServer->setEnabled(true);
 		mServer->setEnabled(true);
+		labelPort->setEnabled(true);
 		mPort->setEnabled(true);
 	}
 
@@ -267,6 +291,12 @@ void JabberEditAccountWidget::sslToggled (bool value)
 			mPort->stepDown ();
 }
 
+void JabberEditAccountWidget::slotPrivacyListsClicked()
+{
+	PrivacyDlg * dialog = new PrivacyDlg (account(), this);
+	dialog->show();
+}
+
 #include "jabbereditaccountwidget.moc"
 
 // vim: set noet ts=4 sts=4 sw=4:
