@@ -1,9 +1,11 @@
 /*
     outgoingtransfer.cpp - msn p2p protocol
 
-    Copyright (c) 2003-2005 by Olivier Goffart        <ogoffart@ kde.org>
+    Copyright (c) 2003-2005 by Olivier Goffart        <ogoffart@kde.org>
     Copyright (c) 2005      by Gregg Edghill          <gregg.edghill@gmail.com>
 
+    Kopete    (c) 2002-2007 by the Kopete developers  <kopete-devel@kde.org>
+
     *************************************************************************
     *                                                                       *
     * This program is free software; you can redistribute it and/or modify  *
@@ -15,14 +17,20 @@
 */
 
 #include "outgoingtransfer.h"
+//Added by qt3to4:
+#include <QByteArray>
+using P2P::TransferContext;
+using P2P::Dispatcher;
+using P2P::OutgoingTransfer;
+using P2P::Message;
 
 #include <stdlib.h>
 
 // Kde includes
-#include <kbufferedsocket.h>
+#include <k3bufferedsocket.h>
 #include <kdebug.h>
 #include <klocale.h>
-#include <kmdcodec.h>
+#include <kcodecs.h>
 using namespace KNetwork;
 
 // Qt includes
@@ -39,7 +47,7 @@ using P2P::Dispatcher;
 using P2P::OutgoingTransfer;
 using P2P::Message;
 
-OutgoingTransfer::OutgoingTransfer(const QString& to, P2P::Dispatcher *dispatcher, Q_UINT32 sessionId)
+OutgoingTransfer::OutgoingTransfer(const QString& to, P2P::Dispatcher *dispatcher, quint32 sessionId)
 : TransferContext(to,dispatcher,sessionId)
 {
 	m_direction = Outgoing;
@@ -48,11 +56,12 @@ OutgoingTransfer::OutgoingTransfer(const QString& to, P2P::Dispatcher *dispatche
 
 OutgoingTransfer::~OutgoingTransfer()
 {
-	kdDebug(14140) << k_funcinfo << endl;
+	kDebug(14140) ;
 }
 
 void OutgoingTransfer::sendImage(const QByteArray& image)
 {
+	Q_UNUSED(image);
 
 // 	TODO QByteArray base64 = KCodecs::base64Encode(image);
 //
@@ -83,13 +92,15 @@ void OutgoingTransfer::sendImage(const QByteArray& image)
 
 void OutgoingTransfer::slotSendData()
 {
-	Q_INT32 bytesRead = 0;
-	QByteArray buffer(1202);
+	qint32 bytesRead = 0;
+	QByteArray buffer;
+	buffer.resize(1202);
+
 	if(!m_file)
 		return;
 
 	// Read a chunk from the source file.
-	bytesRead = m_file->readBlock(buffer.data(), buffer.size());
+	bytesRead = m_file->read(buffer.data(), buffer.size());
 	
 	if (bytesRead < 0) {
 		m_file->close();
@@ -101,7 +112,7 @@ void OutgoingTransfer::slotSendData()
 			buffer.resize(bytesRead);
 		}
 
-		kdDebug(14140) << k_funcinfo << QString("Sending, %1 bytes").arg(bytesRead) << endl;
+		kDebug(14140) << QString("Sending, %1 bytes").arg(bytesRead);
 
 		if((m_offset + bytesRead) < m_file->size())
 		{
@@ -130,7 +141,7 @@ void OutgoingTransfer::slotSendData()
 
 void OutgoingTransfer::acknowledged()
 {
-	kdDebug(14140) << k_funcinfo << endl;
+	kDebug(14140) ;
 
 	switch(m_state)
 	{
@@ -194,8 +205,8 @@ void OutgoingTransfer::acknowledged()
 void OutgoingTransfer::processMessage(const Message& message)
 {
 	QString body =
-		QCString(message.body.data(), message.header.dataSize);
-	kdDebug(14140) << k_funcinfo << "received, " << body << endl;
+		QByteArray(message.body.data(), message.header.dataSize);
+	kDebug(14140) << "received, " << body;
 
 	if(body.startsWith("BYE"))
 	{
@@ -204,11 +215,11 @@ void OutgoingTransfer::processMessage(const Message& message)
 		acknowledge(message);
 		if(!m_isComplete)
 		{
-			// The peer cancelled the transfer.
+			// The peer canceled the transfer.
 			if(m_transfer)
 			{
-				// Inform the user of the file transfer cancelation.
-				m_transfer->slotError(KIO::ERR_ABORTED, i18n("File transfer canceled."));
+				// Inform the user of the file transfer cancellation.
+				m_transfer->slotError(KIO::ERR_ABORTED, i18n("File transfer cancelled."));
 			}
 		}
 		// Dispose of this transfer context.
@@ -218,7 +229,7 @@ void OutgoingTransfer::processMessage(const Message& message)
 	{
 		// Retrieve the message content type.
 		QRegExp regex("Content-Type: ([A-Za-z0-9$!*/\\-]*)");
-		regex.search(body);
+		regex.indexIn(body);
 		QString contentType = regex.cap(1);
 
 		if(contentType == "application/x-msnmsgr-sessionreqbody")
@@ -230,7 +241,7 @@ void OutgoingTransfer::processMessage(const Message& message)
 			// Try to open the file for reading.
 			// If an error occurs, send an internal
 			// error message to the recipient.
-			if(!m_file->open(IO_ReadOnly)){
+			if(!m_file->open(QIODevice::ReadOnly)){
 				error();
 				return;
 			}
@@ -244,7 +255,7 @@ void OutgoingTransfer::processMessage(const Message& message)
 			}
 
 			m_transfer =
-				Kopete::TransferManager::transferManager()->addTransfer(contact, m_file->name(), m_file->size(), m_recipient, Kopete::FileTransferInfo::Outgoing);
+				Kopete::TransferManager::transferManager()->addTransfer(contact, m_file->fileName(), m_file->size(), m_recipient, Kopete::FileTransferInfo::Outgoing);
 
 			QObject::connect(m_transfer , SIGNAL(transferCanceled()), this, SLOT(abort()));
 
@@ -267,7 +278,7 @@ void OutgoingTransfer::processMessage(const Message& message)
 			// Determine whether the recipient created
 			// a listening endpoint.
 			regex = QRegExp("Listening: ([^\r\n]+)\r\n");
-			regex.search(body);
+			regex.indexIn(body);
 			bool isListening = (regex.cap(1) == "true");
 
 			// Send the recipient an acknowledge message.
@@ -282,16 +293,16 @@ void OutgoingTransfer::processMessage(const Message& message)
 			{
 				// Retrieve the hashed nonce for this direct connection instance.
 				regex = QRegExp("Hashed-Nonce: \\{([0-9A-F\\-]*)\\}\r\n");
-				regex.search(body);
+				regex.indexIn(body);
 				m_nonce = regex.cap(1);
 				// Retrieve the listening endpoints of the receiving client.
 				regex = QRegExp("IPv4Internal-Addrs: ([^\r\n]+)\r\n");
-				regex.search(body);
-				m_peerEndpoints = QStringList::split(" ", regex.cap(1));
+				regex.indexIn(body);
+				m_peerEndpoints = regex.cap(1).split( " ", QString::SkipEmptyParts );
 				m_endpointIterator = m_peerEndpoints.begin();
 				// Retrieve the listening port of the receiving client.
 				regex = QRegExp("IPv4Internal-Port: ([^\r\n]+)\r\n");
-				regex.search(body);
+				regex.indexIn(body);
 				m_remotePort = regex.cap(1);
 
 				// Try to connect to the receiving client's
@@ -309,13 +320,13 @@ void OutgoingTransfer::processMessage(const Message& message)
 	}
 	else if(body.startsWith("MSNSLP/1.0 603 Decline"))
 	{
-		// File transfer has been cancelled remotely.
+		// File transfer has been canceled remotely.
 		// Send an acknowledge message
 		acknowledge(message);
 		if(m_transfer)
 		{
-			// Inform the user of the file transfer cancelation.
-			m_transfer->slotError(KIO::ERR_ABORTED, i18n("File transfer canceled."));
+			// Inform the user of the file transfer cancellation.
+			m_transfer->slotError(KIO::ERR_ABORTED, i18n("File transfer cancelled."));
 		}
 
 		if(m_file && m_file->isOpen()){
@@ -355,9 +366,9 @@ void OutgoingTransfer::connectToEndpoint(const QString& hostName)
 
 void OutgoingTransfer::slotConnected()
 {
-	kdDebug(14140) << k_funcinfo << endl;
+	kDebug(14140) ;
 	// Check if connection is ok.
-	Q_UINT32 bytesWritten = m_socket->writeBlock(QCString("foo").data(), 4);
+	quint32 bytesWritten = m_socket->write(QByteArray("foo").data(), 4);
 	if(bytesWritten != 4)
 	{
 		// Not all data was written, close the socket.
@@ -381,27 +392,27 @@ void OutgoingTransfer::slotConnected()
 	handshake.header.ackSessionIdentifier = nonce.mid(0, 8).toUInt(0, 16);
 	handshake.header.ackUniqueIdentifier  =
 		nonce.mid(8, 4).toUInt(0, 16) | (nonce.mid(12, 4).toUInt(0, 16) << 16);
-	const Q_UINT32 lo = nonce.mid(16, 8).toUInt(0, 16);
-	const Q_UINT32 hi = nonce.mid(24, 8).toUInt(0, 16);
+	const quint32 lo = nonce.mid(16, 8).toUInt(0, 16);
+	const quint32 hi = nonce.mid(24, 8).toUInt(0, 16);
 	handshake.header.ackDataSize =
-		((Q_INT64)htonl(lo)) | (((Q_INT64)htonl(hi)) << 32);
+		((qint64)htonl(lo)) | (((qint64)htonl(hi)) << 32);
 
 	QByteArray stream;
 	// Write the message to the memory stream.
 	m_messageFormatter.writeMessage(handshake, stream, true);
 	// Send the byte stream over the wire.
-	m_socket->writeBlock(stream.data(), stream.size());
+	m_socket->write(stream.data(), stream.size());
 }
 
 void OutgoingTransfer::slotRead()
 {
-	Q_INT32 bytesAvailable = m_socket->bytesAvailable();
-	kdDebug(14140) << k_funcinfo << bytesAvailable << ", bytes available." << endl;
+	qint32 bytesAvailable = m_socket->bytesAvailable();
+	kDebug(14140) << bytesAvailable << ", bytes available.";
 }
 
 void OutgoingTransfer::slotSocketError(int)
 {
-	kdDebug(14140) << k_funcinfo << m_socket->errorString() << endl;
+	kDebug(14140) << m_socket->errorString();
 	// If an error has occurred, try to connect
 	// to another available peer endpoint.
 	// If there are no more available endpoints,
@@ -424,7 +435,7 @@ void OutgoingTransfer::slotSocketError(int)
 
 void OutgoingTransfer::slotSocketClosed()
 {
-	kdDebug(14140) << k_funcinfo << endl;
+	kDebug(14140) ;
 	m_socket->deleteLater();
 	m_socket = 0l;
 }
