@@ -5,8 +5,9 @@
     Copyright (c) 2005 Matt Rogers <mattr@kde.org>
     Copyright (c) 2005 Conrad Hoffmann <conrausch@gmx.de>
     Copyright (c) 2005 Gustavo Pichorim Boiko <gustavo.boiko@kdemail.net>
+    Copyright (c) 2006-2007 Roman Jarosz <kedgedev@centrum.cz>
 
-    Kopete (c) 2002-2005 by the Kopete developers <kopete-devel@kde.org>
+    Kopete (c) 2002-2007 by the Kopete developers <kopete-devel@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -21,11 +22,11 @@
 #ifndef _OSCARMESSAGE_H_
 #define _OSCARMESSAGE_H_
 
-#include <qglobal.h>
-#include <qstring.h>
-#include <qcstring.h>
-#include <qdatetime.h>
-#include "kopete_export.h"
+
+#include <QDateTime>
+#include <QSharedDataPointer>
+
+#include "liboscar_export.h"
 #include "oscartypes.h"
 
 class QTextCodec;
@@ -33,6 +34,8 @@ class QTextCodec;
 namespace Oscar
 {
 
+	class MessagePlugin;
+
 /**
  * This class is responsible for holding all the details
  * of a message and includes the following:
@@ -40,7 +43,32 @@ namespace Oscar
  * \li encoding
  */
 
-class KOPETE_EXPORT Message
+namespace MessageType
+{
+	enum {
+		Unknown      = 0x00, // Unknown
+		Plain        = 0x01, // Plain text (simple) message
+		Chat         = 0x02, // Chat request message
+		File         = 0x03, // File request / file ok message
+		Url          = 0x04, // URL message (0xFE formatted)
+		AuthRequest  = 0x06, // Authorization request message (0xFE formatted)
+		AuthDeny     = 0x07, // Authorization denied message (0xFE formatted)
+		AuthGranted  = 0x08, // Authorization given message (empty)
+		Server       = 0x09, // Message from OSCAR server (0xFE formatted)
+		Added        = 0x0C, // "You-were-added" message (0xFE formatted)
+		WebPager     = 0x0D, // Web pager message (0xFE formatted)
+		EmailExpress = 0x0E, // Email express message (0xFE formatted)
+		ContactList  = 0x13, // Contact list message
+		Plugin       = 0x1A, // Plugin message described by text string
+		AutoAway     = 0xE8, // Auto away message
+		AutoBusy     = 0xE9, // Auto occupied message
+		AutoNA       = 0xEA, // Auto not available message
+		AutoDND      = 0xEB, // Auto do not disturb message
+		AutoFFC      = 0xEC  // Auto free for chat message
+	};
+}
+
+class LIBOSCAR_EXPORT Message
 {
 public:
 
@@ -56,15 +84,20 @@ public:
 
 	enum Encoding {
 		UserDefined,
+		ASCII,
+		LATIN1,
 		UTF8,
 		UCS2
 	};
 
 	Message();
 
-	Message( Encoding messageEncoding, const QByteArray& messageText, int channel, int properties, QDateTime timestamp );
-	Message( Encoding messageEncoding, const QCString& messageText, int channel, int properties, QDateTime timestamp );
-	Message( Encoding messageEncoding, const QString& messageText, int channel, int properties, QDateTime timestamp, QTextCodec* codec = 0 );
+// 	Message( Encoding messageEncoding, const QByteArray& messageText, int channel, int properties, QDateTime timestamp );
+// 	Message( Encoding messageEncoding, const QString& messageText, int channel, int properties, QDateTime timestamp, QTextCodec* codec = 0 );
+
+	Message( const Message& m );
+	Message& operator=( const Message& m );
+	~Message();
 
 	/** Get the sender of the message */
 	QString sender() const;
@@ -81,6 +114,9 @@ public:
 	/** get the message text */
 	QString text( QTextCodec* codec ) const;
 
+	/** get best encoding for text */
+	static Message::Encoding encodingForText( const QString& newText, bool allowUCS2 = false );
+
 	/** set the message text */
 	void setText( Encoding newEncoding, const QString& newText, QTextCodec* codec  = 0);
 
@@ -90,9 +126,6 @@ public:
 	/** set the message text as a bytearray for decoding */
 	void setTextArray( const QByteArray& newTextArray );
 
-	/** set the mesasge text as a bytearray for decoding */
-	void setTextArray( const QCString& newTextArray );
-
 	/** get the message properties */
 	int properties() const;
 
@@ -102,11 +135,11 @@ public:
 	/** add a property to the message */
 	void addProperty( int prop );
 
-	/** get the channel ( type ) of the message */
-	int type() const;
+	/** get the channel ( NOT type ) of the message */
+	int channel() const;
 
-	/** set the channel ( type ) of the message */
-	void setType( int newType );
+	/** set the channel ( NOT type ) of the message */
+	void setChannel( int newChannel );
 
 	/** get the timestamp of the message */
 	QDateTime timestamp() const;
@@ -138,6 +171,48 @@ public:
 	/** set the message (content) type */
 	void setMessageType( int type );
 
+	/** get the request type (req/cancel/accept) */
+	int requestType() const;
+
+	/** set the request type (req/cancel/accept) */
+	void setRequestType( int type );
+
+	/** get the port */
+	int port() const;
+
+	/** set the port (for transfer requests) */
+	void setPort( int port );
+
+	/** get the proxy ip*/
+	QByteArray proxy() const;
+
+	/** set the proxy ip (for transfer requests) */
+	void setProxy( QByteArray proxy );
+
+	/** get the request # */
+	int requestNumber() const;
+
+	/** set the request # (for transfer requests) */
+	void setRequestNumber( int n );
+
+	/** get the file name */
+	QString fileName() const;
+
+	/** get file(s) size */
+	DWORD filesSize() const;
+
+	/** get file count */
+	WORD fileCount() const;
+
+	/** set the file name (for transfer requests) */
+	void setFileName( const QString &name );
+
+	/** set file(s) size (for transfer requests)*/
+	void setFilesSize( DWORD size );
+	
+	/** set file count (for transfer requests)*/
+	void setFileCount( WORD count );
+
     /** get the exchange for the chat room this message is for */
     Oscar::WORD exchange() const;
 
@@ -156,23 +231,20 @@ public:
 	/** set the message encoding */
 	void setEncoding( Encoding newEncoding );
 
+	/** get the message plugin */
+	MessagePlugin* plugin() const;
+
+	/** set the message plugin
+	 *  The message deletes old plugin when a new plugin is set.
+	 */
+	void setPlugin( MessagePlugin* plugin );
+
 	operator bool() const;
 
 private:
-    //TODO d-pointer
-	QString m_sender;
-	QString m_receiver;
-	int m_channel;
-	int m_properties;
-	int m_messageType;
-	int m_protocolVersion;
-	int m_channel2Counter;
-	QByteArray m_icbmCookie;
-	QByteArray m_textArray;
-	QDateTime m_timestamp;
-	Oscar::WORD m_exchange;
-	QString m_chatRoom;
-	Encoding m_encoding;
+	class MessagePrivate;
+	QSharedDataPointer<MessagePrivate> d;
+
 };
 
 }
