@@ -1,7 +1,7 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: general.cpp 430603 2005-07-01 22:31:27Z porten $
+ * $Id: general.cpp 766873 2008-01-26 20:24:26Z porten $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -21,12 +21,18 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <termios.h>
 #include <string.h>
-#include <qwhatsthis.h>
+
+//Added by qt3to4:
+#include <QLabel>
+#include <QVBoxLayout>
+#include <QFrame>
+#include <QHBoxLayout>
+#include <QGridLayout>
 
 #include <knuminput.h>
 #include <qslider.h>
@@ -39,7 +45,7 @@
 #include "pppdata.h"
 #include <klocale.h>
 #include <qlayout.h>
-#include <qgrid.h>
+#include <q3grid.h>
 
 /////////////////////////////////////////////////////////////////////////////
 //
@@ -47,11 +53,16 @@
 //
 /////////////////////////////////////////////////////////////////////////////
 GeneralWidget::GeneralWidget( QWidget *parent, const char *name)
-  : QWidget(parent, name)
+  : QWidget(parent)
 {
-  QVBoxLayout *tl = new QVBoxLayout(parent, 0, KDialog::spacingHint());
+  setObjectName(name);
 
-  QHBoxLayout *hbox = new QHBoxLayout(tl);
+  QVBoxLayout *tl = new QVBoxLayout(parent);
+  tl->setSpacing(KDialog::spacingHint());
+  tl->setMargin(0);
+
+  QHBoxLayout *hbox = new QHBoxLayout();
+  tl->addItem(hbox);
   QLabel *label;
   label = new QLabel(i18n("pppd version:"), parent);
   hbox->addWidget(label);
@@ -64,7 +75,8 @@ GeneralWidget::GeneralWidget( QWidget *parent, const char *name)
 
   KIntNumInput *pppdTimeout = new KIntNumInput(gpppdata.pppdTimeout(), parent);
   pppdTimeout->setLabel(i18n("pppd &timeout:"));
-  pppdTimeout->setRange(1, TIMEOUT_SIZE, 5, true);
+  pppdTimeout->setRange(1, TIMEOUT_SIZE, 5);
+  pppdTimeout->setSliderEnabled(true);
   pppdTimeout->setSuffix(i18n(" sec"));
   connect(pppdTimeout, SIGNAL(valueChanged(int)),
           SLOT(pppdtimeoutchanged(int)));
@@ -73,14 +85,13 @@ GeneralWidget::GeneralWidget( QWidget *parent, const char *name)
 		     "to see if a PPP connection is established.\n"
 		     "If no connection is made in this time frame,\n"
 		     "<i>kppp</i> will give up and kill pppd.");
-  QWhatsThis::add(pppdTimeout,tmp);
-  label->setBuddy(pppdTimeout);
+  pppdTimeout->setWhatsThis(tmp);
 
   tl->addSpacing(10);
 
   QCheckBox *chkBox;
   chkBox = new QCheckBox(i18n("Doc&k into panel on connect"), parent);
-  QWhatsThis::add(chkBox,
+  chkBox->setWhatsThis(
 		  i18n("<p>After a connection is established, the\n"
 		       "window is minimized and a small icon\n"
 		       "in the KDE panel represents this window.\n"
@@ -99,7 +110,7 @@ GeneralWidget::GeneralWidget( QWidget *parent, const char *name)
   connect(chkBox,SIGNAL(toggled(bool)),
 	  this, SLOT(redial_toggled(bool)));
   tl->addWidget(chkBox);
-  QWhatsThis::add(chkBox,
+  chkBox->setWhatsThis(
 		  i18n("<p>When a connection is established and\n"
 		       "it somehow gets disconnected, <i>kppp</i>\n"
 		       "will try to reconnect to the same account.\n"
@@ -111,7 +122,7 @@ GeneralWidget::GeneralWidget( QWidget *parent, const char *name)
   connect(chkBox,SIGNAL(toggled(bool)),
 	  this, SLOT(nocarrier_toggled(bool)));
   tl->addWidget(chkBox);
-  QWhatsThis::add(chkBox,
+  chkBox->setWhatsThis(
 		  i18n("<p>When dialing if modem returns NO CARRIER\n"
 		       "the program will make a new attempt to redial\n"
 		       "instead of waiting for user to click <CANCEL>\n"
@@ -122,7 +133,7 @@ GeneralWidget::GeneralWidget( QWidget *parent, const char *name)
   connect(chkBox, SIGNAL(toggled(bool)),
 	  this, SLOT(caption_toggled(bool)));
   tl->addWidget(chkBox);
-  QWhatsThis::add(chkBox,
+  chkBox->setWhatsThis(
 		  i18n("When this option is checked, the window\n"
 		       "title shows the time since a connection\n"
 		       "was established. Very useful, so you \n"
@@ -133,7 +144,7 @@ GeneralWidget::GeneralWidget( QWidget *parent, const char *name)
   connect(chkBox, SIGNAL(toggled(bool)),
 	  this, SLOT(xserver_toggled(bool)));
   tl->addWidget(chkBox);
-  QWhatsThis::add(chkBox,
+  chkBox->setWhatsThis(
 		  i18n("<p>Checking this option will close any\n"
 		       "open connection when the X-server is\n"
 		       "shut down. You should enable this option\n"
@@ -146,7 +157,7 @@ GeneralWidget::GeneralWidget( QWidget *parent, const char *name)
   connect(chkBox, SIGNAL(toggled(bool)),
 	  this, SLOT(quit_toggled(bool)));
   tl->addWidget(chkBox);
-  QWhatsThis::add(chkBox,
+  chkBox->setWhatsThis(
 		  i18n("When this option is turned on, <i>kppp</i>\n"
 		       "will be closed when you disconnect"));
 
@@ -155,7 +166,7 @@ GeneralWidget::GeneralWidget( QWidget *parent, const char *name)
   connect(chkBox,SIGNAL(toggled(bool)),
 	  this,SLOT(iconify_toggled(bool)));
   tl->addWidget(chkBox);
-  QWhatsThis::add(chkBox,
+  chkBox->setWhatsThis(
 		  i18n("Iconifies <i>kppp</i>'s window when a\n"
 		       "connection is established"));
 
@@ -203,28 +214,35 @@ void GeneralWidget::pppdtimeoutchanged(int n) {
 }
 
 
-ModemWidget::ModemWidget(QWidget *parent, bool isnewmodem, const char *name)
-  : QWidget(parent, name)
+ModemWidget::ModemWidget(QWidget *parent, bool isnewmodem)
+  : QWidget(parent)
 {
-  QGridLayout *tl = new QGridLayout(parent, 9, 2, 0, KDialog::spacingHint());
+  QVBoxLayout *topLayout = new QVBoxLayout(parent);
+  topLayout->setSpacing(KDialog::spacingHint());
+  topLayout->setMargin(0);
+  topLayout->addWidget(this);
 
-  connect_label = new QLabel(i18n("Modem &name:"), parent);
+  QGridLayout *tl = new QGridLayout(this );
+  tl->setSpacing( KDialog::spacingHint() );
+
+  connect_label = new QLabel(i18n("Modem &name:"), this);
   tl->addWidget(connect_label, 0, 0);
 
-  connectname_l = new QLineEdit(parent);
+  connectname_l = new QLineEdit(this);
   connectname_l->setMaxLength(ACCNAME_SIZE);
   connect_label->setBuddy(connectname_l);
 
   tl->addWidget(connectname_l, 0, 1);
   QString tmp = i18n("Type in a unique name for this modem");
 
-  QWhatsThis::add(connect_label,tmp);
-  QWhatsThis::add(connectname_l,tmp);
+  connect_label->setWhatsThis(tmp);
+  connectname_l->setWhatsThis(tmp);
 
-  label1 = new QLabel(i18n("Modem de&vice:"), parent);
+  label1 = new QLabel(i18n("Modem de&vice:"), this);
   tl->addWidget(label1, 1, 0);
 
-  modemdevice = new QComboBox(false, parent);
+  modemdevice = new QComboBox(this);
+  modemdevice->setEditable( false );
   label1->setBuddy(modemdevice);
   // ### deviceExist mechanism not functional right now
   bool deviceExist = false;
@@ -232,10 +250,10 @@ ModemWidget::ModemWidget(QWidget *parent, bool isnewmodem, const char *name)
   {
       if ( devices[k] == gpppdata.modemDevice())
           deviceExist = true;
-    modemdevice->insertItem(devices[k]);
+    modemdevice->addItem(devices[k]);
   }
   if ( !deviceExist )
-      modemdevice->insertItem(gpppdata.modemDevice());
+      modemdevice->addItem(gpppdata.modemDevice());
 
   tl->addWidget(modemdevice, 1, 1);
 /*  connect(modemdevice, SIGNAL(activated(int)),
@@ -248,18 +266,19 @@ ModemWidget::ModemWidget(QWidget *parent, bool isnewmodem, const char *name)
 		     "emulation (most cards under Linux support this), you\n"
 		     "should select one of the /dev/ttyIx devices.");
 
-  QWhatsThis::add(label1,tmp);
-  QWhatsThis::add(modemdevice,tmp);
+  label1->setWhatsThis(tmp);
+  modemdevice->setWhatsThis(tmp);
 
 
-  label2 = new QLabel(i18n("&Flow control:"), parent);
+  label2 = new QLabel(i18n("&Flow control:"), this);
   tl->addWidget(label2, 2, 0);
 
-  flowcontrol = new QComboBox(false, parent);
+  flowcontrol = new QComboBox(this);
+  flowcontrol->setEditable( false );
   label2->setBuddy(flowcontrol);
-  flowcontrol->insertItem(i18n("Hardware [CRTSCTS]")); // sync with pppdata.cpp
-  flowcontrol->insertItem(i18n("Software [XON/XOFF]"));
-  flowcontrol->insertItem(i18n("None"));
+  flowcontrol->addItem(i18n("Hardware [CRTSCTS]")); // sync with pppdata.cpp
+  flowcontrol->addItem(i18n("Software [XON/XOFF]"));
+  flowcontrol->addItem(i18n("None"));
 
   flowListItem << "Hardware [CRTSCTS]";
   flowListItem << "Software [XON/XOFF]";
@@ -275,17 +294,18 @@ ModemWidget::ModemWidget(QWidget *parent, bool isnewmodem, const char *name)
 	     "\n"
 	     "<b>Default</b>: CRTSCTS");
 
-  QWhatsThis::add(label2,tmp);
-  QWhatsThis::add(flowcontrol,tmp);
+  label2->setWhatsThis(tmp);
+  flowcontrol->setWhatsThis(tmp);
 
-  labelenter = new QLabel(i18n("&Line termination:"), parent);
+  labelenter = new QLabel(i18n("&Line termination:"), this);
   tl->addWidget(labelenter, 3, 0);
 
-  enter = new QComboBox(false, parent);
+  enter = new QComboBox(this);
+  enter->setEditable( false );
   labelenter->setBuddy(enter);
-  enter->insertItem("CR");
-  enter->insertItem("LF");
-  enter->insertItem("CR/LF");
+  enter->addItem("CR");
+  enter->addItem("LF");
+  enter->addItem("CR/LF");
   tl->addWidget(enter, 3, 1);
  /* connect(enter, SIGNAL(activated(int)), SLOT(setenter(int)));*/
   tmp = i18n("<p>Specifies how AT commands are sent to your\n"
@@ -296,12 +316,12 @@ ModemWidget::ModemWidget(QWidget *parent, bool isnewmodem, const char *name)
 	     "\n"
 	     "<b>Default</b>: CR/LF");
 
-  QWhatsThis::add(labelenter,tmp);
-  QWhatsThis::add(enter, tmp);
+  labelenter->setWhatsThis(tmp);
+  enter->setWhatsThis( tmp);
 
-  baud_label = new QLabel(i18n("Co&nnection speed:"), parent);
+  baud_label = new QLabel(i18n("Co&nnection speed:"), this);
   tl->addWidget(baud_label, 4, 0);
-  baud_c = new QComboBox(parent);
+  baud_c = new QComboBox(this);
   baud_label->setBuddy(baud_c);
 
   static const char *baudrates[] = {
@@ -329,9 +349,9 @@ ModemWidget::ModemWidget(QWidget *parent, bool isnewmodem, const char *name)
     0};
 
   for(int k = 0; baudrates[k]; k++)
-    baud_c->insertItem(baudrates[k]);
+    baud_c->addItem(baudrates[k]);
 
-  baud_c->setCurrentItem(3);
+  baud_c->setCurrentIndex(3);
   /*connect(baud_c, SIGNAL(activated(int)),
 	  this, SLOT(speed_selection(int)));*/
   tl->addWidget(baud_c, 4, 1);
@@ -343,25 +363,25 @@ ModemWidget::ModemWidget(QWidget *parent, bool isnewmodem, const char *name)
 	     "If you have connection problems, try to reduce\n"
 	     "this value.");
 
-  QWhatsThis::add(baud_label,tmp);
-  QWhatsThis::add(baud_c,tmp);
+  baud_label->setWhatsThis(tmp);
+  baud_c->setWhatsThis(tmp);
 
   for(int i=0; i <= enter->count()-1; i++) {
-    if(gpppdata.enter() == enter->text(i))
-      enter->setCurrentItem(i);
+    if(gpppdata.enter() == enter->itemText(i))
+      enter->setCurrentIndex(i);
   }
 
-  tl->addRowSpacing(4, 10);
+  tl->addItem(new QSpacerItem(0, 10), 4, 0);
 
   //Modem Lock File
-  modemlockfile = new QCheckBox(i18n("&Use lock file"), parent);
+  modemlockfile = new QCheckBox(i18n("&Use lock file"), this);
 
   modemlockfile->setChecked(gpppdata.modemLockFile());
 /*  connect(modemlockfile, SIGNAL(toggled(bool)),
           SLOT(modemlockfilechanged(bool)));*/
-  tl->addMultiCellWidget(modemlockfile, 5, 5, 0, 1);
+  tl->addWidget(modemlockfile, 5, 0, 1, 2);
   //  l12->addStretch(1);
-  QWhatsThis::add(modemlockfile,
+  modemlockfile->setWhatsThis(
 		  i18n("<p>To prevent other programs from accessing the\n"
 		       "modem while a connection is established, a\n"
 		       "file can be created to indicate that the modem\n"
@@ -374,15 +394,15 @@ ModemWidget::ModemWidget(QWidget *parent, bool isnewmodem, const char *name)
 
   // Modem Timeout Line Edit Box
 
-  modemtimeout = new KIntNumInput(gpppdata.modemTimeout(), parent);
+  modemtimeout = new KIntNumInput(gpppdata.modemTimeout(), this);
   modemtimeout->setLabel(i18n("Modem &timeout:"));
   modemtimeout->setRange(1, 120, 1);
   modemtimeout->setSuffix(i18n(" sec"));
 /*  connect(modemtimeout, SIGNAL(valueChanged(int)),
 	  SLOT(modemtimeoutchanged(int)));*/
-  tl->addMultiCellWidget(modemtimeout, 6, 6, 0, 1);
+  tl->addWidget(modemtimeout, 6, 0, 1, 2);
 
-  QWhatsThis::add(modemtimeout,
+  modemtimeout->setWhatsThis(
                   i18n("This specifies how long <i>kppp</i> waits for a\n"
                        "<i>CONNECT</i> response from your modem. The\n"
                        "recommended value is 30 seconds."));
@@ -393,30 +413,30 @@ ModemWidget::ModemWidget(QWidget *parent, bool isnewmodem, const char *name)
 
   //set stuff from gpppdata
   for(int i=0; i <= enter->count()-1; i++) {
-    if(gpppdata.enter() == enter->text(i))
-      enter->setCurrentItem(i);
+    if(gpppdata.enter() == enter->itemText(i))
+      enter->setCurrentIndex(i);
   }
 
   for(int i=0; i <= modemdevice->count()-1; i++) {
-    if(gpppdata.modemDevice() == modemdevice->text(i))
-      modemdevice->setCurrentItem(i);
+    if(gpppdata.modemDevice() == modemdevice->itemText(i))
+      modemdevice->setCurrentIndex(i);
   }
 
   for(int i=0; i <= flowcontrol->count()-1; i++)
     if(gpppdata.flowcontrol() == flowListItem[i])
-      flowcontrol->setCurrentItem(i);
+      flowcontrol->setCurrentIndex(i);
 
 	//set the modem speed
   for(int i=0; i < baud_c->count(); i++)
-    if(baud_c->text(i) == gpppdata.speed())
-      baud_c->setCurrentItem(i);
+    if(baud_c->itemText(i) == gpppdata.speed())
+      baud_c->setCurrentIndex(i);
 
   } else {
 	//Set the standard Items
-		enter->setCurrentItem(0);
-		modemdevice->setCurrentItem(0);
-		flowcontrol->setCurrentItem(0);
-		baud_c->setCurrentItem(0);
+		enter->setCurrentIndex(0);
+		modemdevice->setCurrentIndex(0);
+		flowcontrol->setCurrentIndex(0);
+		baud_c->setCurrentIndex(0);
 	}
 
   tl->setRowStretch(7, 1);
@@ -430,11 +450,11 @@ bool ModemWidget::save()
     return false;
   } else {
     gpppdata.setModname(connectname_l->text());
-    gpppdata.setSpeed(baud_c->text(baud_c->currentItem()));
-    gpppdata.setEnter(enter->text(enter->currentItem()));
-    gpppdata.setModemDevice(modemdevice->text(modemdevice->currentItem()));
-    gpppdata.setFlowcontrol(flowListItem[flowcontrol->currentItem()]);
-    gpppdata.setModemLockFile(modemlockfile->isOn());
+    gpppdata.setSpeed(baud_c->itemText(baud_c->currentIndex()));
+    gpppdata.setEnter(enter->itemText(enter->currentIndex()));
+    gpppdata.setModemDevice(modemdevice->itemText(modemdevice->currentIndex()));
+    gpppdata.setFlowcontrol(flowListItem[flowcontrol->currentIndex()]);
+    gpppdata.setModemLockFile(modemlockfile->isChecked());
     gpppdata.setModemTimeout(modemtimeout->value());
     return true;
    }
@@ -442,16 +462,25 @@ bool ModemWidget::save()
 
 
 ModemWidget2::ModemWidget2(QWidget *parent, const char *name)
-  : QWidget(parent, name)
+  : QWidget(parent)
 {
-  QVBoxLayout *l1 = new QVBoxLayout(parent, 0, KDialog::spacingHint());
+  setObjectName(name);
+
+  QVBoxLayout *topLayout = new QVBoxLayout(parent);
+  topLayout->setSpacing(KDialog::spacingHint());
+  topLayout->setMargin(0);
+  topLayout->addWidget(this);
+
+  QVBoxLayout *l1 = new QVBoxLayout(this);
+  l1->setSpacing(KDialog::spacingHint());
+  l1->setMargin(0);
 
 
-  waitfordt = new QCheckBox(i18n("&Wait for dial tone before dialing"), parent);
+  waitfordt = new QCheckBox(i18n("&Wait for dial tone before dialing"), this);
   waitfordt->setChecked(gpppdata.waitForDialTone());
  // connect(waitfordt, SIGNAL(toggled(bool)), SLOT(waitfordtchanged(bool)));
   l1->addWidget(waitfordt);
-  QWhatsThis::add(waitfordt,
+  waitfordt->setWhatsThis(
 		  i18n("<p>Normally the modem waits for a dial tone\n"
 		       "from your phone line, indicating that it can\n"
 		       "start to dial a number. If your modem does not\n"
@@ -460,14 +489,15 @@ ModemWidget2::ModemWidget2(QWidget *parent, const char *name)
 		       "\n"
 		       "<b>Default:</b>: On"));
 
-  busywait = new KIntNumInput(gpppdata.busyWait(), parent);
+  busywait = new KIntNumInput(gpppdata.busyWait(), this);
   busywait->setLabel(i18n("B&usy wait:"));
-  busywait->setRange(0, 300, 5, true);
+  busywait->setRange(0, 300, 5);
+  busywait->setSliderEnabled(true);
   busywait->setSuffix(i18n(" sec"));
  // connect(busywait, SIGNAL(valueChanged(int)), SLOT(busywaitchanged(int)));
   l1->addWidget(busywait);
 
-  QWhatsThis::add(busywait,
+  busywait->setWhatsThis(
                   i18n("Specifies the number of seconds to wait before\n"
                        "redial if all dialed numbers are busy. This is\n"
                        "necessary because some modems get stuck if the\n"
@@ -481,11 +511,15 @@ ModemWidget2::ModemWidget2(QWidget *parent, const char *name)
   QHBoxLayout *hbl = new QHBoxLayout;
   hbl->setSpacing(KDialog::spacingHint());
 
-  QLabel *volumeLabel = new QLabel(i18n("Modem &volume:"), parent);
+  QLabel *volumeLabel = new QLabel(i18n("Modem &volume:"), this);
   hbl->addWidget(volumeLabel);
-  volume = new QSlider(0, 2, 1, gpppdata.volume(), QSlider::Horizontal, parent);
+  volume = new QSlider(Qt::Horizontal, this);
+  volume->setMinimum(0);
+  volume->setMaximum(2);
+  volume->setPageStep(1);
+  volume->setValue(gpppdata.volume());
   volumeLabel->setBuddy(volume);
-  volume->setTickmarks(QSlider::Below);
+  volume->setTickPosition(QSlider::TicksBelow);
   hbl->addWidget(volume);
 
   l1->addLayout(hbl);
@@ -500,20 +534,20 @@ ModemWidget2::ModemWidget2(QWidget *parent, const char *name)
 	     "If this does not work for your modem,\n"
 	     "you must modify the modem volume command.");
 
-  QWhatsThis::add(volumeLabel,tmp);
-  QWhatsThis::add(volume, tmp);
+  volumeLabel->setWhatsThis(tmp);
+  volume->setWhatsThis( tmp);
 
   l1->addSpacing(20);
 
 #if 0
-  chkbox1 = new QCheckBox(i18n("Modem asserts CD line"), parent);
+  chkbox1 = new QCheckBox(i18n("Modem asserts CD line"), this);
   chkbox1->setChecked(gpppdata.UseCDLine());
   connect(chkbox1,SIGNAL(toggled(bool)),
 	  this,SLOT(use_cdline_toggled(bool)));
   l12->addWidget(chkbox1);
   l12->addStretch(1);
   l1->addStretch(1);
-  QWhatsThis::add(chkbox1,
+  chkbox1->setWhatsThis(
 		  i18n("This controls how <i>kppp</i> detects that the modem\n"
 		       "is not responding. Unless you are having\n"
 		       "problems with this, do not modify this setting.\n"
@@ -521,13 +555,13 @@ ModemWidget2::ModemWidget2(QWidget *parent, const char *name)
 		       "<b>Default</b>: Off"));
 #endif
 
-  modemcmds = new QPushButton(i18n("Mod&em Commands..."), parent);
-  QWhatsThis::add(modemcmds,
+  modemcmds = new QPushButton(i18n("Mod&em Commands..."), this);
+  modemcmds->setWhatsThis(
 		  i18n("Allows you to change the AT command for\n"
 		       "your modem."));
 
-  modeminfo_button = new QPushButton(i18n("&Query Modem..."), parent);
-  QWhatsThis::add(modeminfo_button,
+  modeminfo_button = new QPushButton(i18n("&Query Modem..."), this);
+  modeminfo_button->setWhatsThis(
 		  i18n("Most modems support the ATI command set to\n"
 		       "find out vendor and revision of your modem.\n"
 		       "\n"
@@ -535,8 +569,8 @@ ModemWidget2::ModemWidget2(QWidget *parent, const char *name)
 		       "this information. It can be useful to help\n"
 		       "you set up the modem"));
 
-  terminal_button = new QPushButton(i18n("&Terminal..."), parent);
-  QWhatsThis::add(terminal_button,
+  terminal_button = new QPushButton(i18n("&Terminal..."), this);
+  terminal_button->setWhatsThis(
 		  i18n("Opens the built-in terminal program. You\n"
 		       "can use this if you want to play around\n"
 		       "with your modem's AT command set"));
@@ -591,7 +625,7 @@ void ModemWidget2::use_cdline_toggled(bool on) {
 
 bool ModemWidget2::save()
 {
-  gpppdata.setWaitForDialTone(waitfordt->isOn());
+  gpppdata.setWaitForDialTone(waitfordt->isChecked());
   gpppdata.setbusyWait(busywait->value());
   gpppdata.setVolume(volume->value());
   return true;
@@ -603,41 +637,41 @@ bool ModemWidget2::save()
 // Setup widget for the graph
 //
 /////////////////////////////////////////////////////////////////////////////
-GraphSetup::GraphSetup(QWidget *parent, const char *name) :
-  QWidget(parent, name)
+GraphSetup::GraphSetup(QWidget *parent) :
+  QWidget(parent)
 {
-  QVBoxLayout *tl = new QVBoxLayout(parent);
+  QVBoxLayout *tl = new QVBoxLayout(this);
 
   bool enable;
   QColor bg, text, in, out;
   gpppdata.graphingOptions(enable, bg, text, in, out);
 
-  enable_check = new QCheckBox(i18n("&Enable throughput graph"), parent);
+  enable_check = new QCheckBox(i18n("&Enable throughput graph"), this);
   tl->addWidget(enable_check);
 
-  grpColor = new QGroupBox(2, Qt::Horizontal,
-        i18n("Graph Colors"), parent);
+  grpColor = new Q3GroupBox(2, Qt::Horizontal,
+        i18n("Graph Colors"), this);
   tl->addWidget(grpColor);
 
   QLabel *label;
 
   label = new QLabel(i18n("Bac&kground:"), grpColor);
-  bg_color = new KColorButton(bg, grpColor);
+  bg_color = new KColorButton( bg, grpColor );
   bg_color->setFixedSize(80, 24);
   label->setBuddy(bg_color);
 
   label = new QLabel(i18n("&Text:"), grpColor);
-  text_color = new KColorButton(text, grpColor);
+  text_color = new KColorButton( text,grpColor );
   text_color->setFixedSize(80, 24);
   label->setBuddy(text_color);
 
   label = new QLabel(i18n("I&nput bytes:"), grpColor);
-  in_color = new KColorButton(in, grpColor);
+  in_color = new KColorButton( in,grpColor );
   in_color->setFixedSize(80, 24);
   label->setBuddy(in_color);
 
   label = new QLabel(i18n("O&utput bytes:"), grpColor);
-  out_color = new KColorButton(out, grpColor);
+  out_color = new KColorButton( out, grpColor );
   out_color->setFixedSize(80, 24);
   label->setBuddy(out_color);
 
