@@ -1,7 +1,7 @@
 /*
  *            kPPP: A front end for pppd for the KDE project
  *
- * $Id: modemcmds.cpp 311457 2004-05-14 16:57:06Z sgotti $
+ * $Id: modemcmds.cpp 741570 2007-11-25 21:49:44Z krake $
  *
  * Copyright (C) 1997 Bernd Johannes Wuebben
  * wuebben@math.cornell.edu
@@ -21,34 +21,43 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with dummyWidget program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <qlayout.h>
 #include <qslider.h>
-#include <kbuttonbox.h>
+//Added by qt3to4:
+#include <QVBoxLayout>
+#include <QHBoxLayout>
+#include <QGridLayout>
 #include <stdlib.h>
-#include <kapplication.h> // for getMiniIcon()
 #include <klocale.h>
 #include "modemcmds.h"
 #include "pppdata.h"
-#include <kwin.h>
-
-#include <qgroupbox.h>
+#include <kwindowsystem.h>
+#include <QFrame>
+#include <QApplication>
+#include <q3groupbox.h>
 #include <qlineedit.h>
 #include <qpushbutton.h>
 #include <qlabel.h>
+#include <kiconloader.h>
 
 
 #define ADJUSTEDIT(e) e->setText("XXXXXXXXqy"); e->setMinimumSize(e->sizeHint()); e->setFixedHeight(e->sizeHint().height()); e->setText(""); e->setMaxLength(MODEMSTR_SIZE);
 
 // a little trick to make the label look like a disabled lineedit
-#define FORMATSLIDERLABEL(l) l->setFixedWidth(l->sizeHint().width()); l->setFixedHeight(QLineEdit(dummyWidget).sizeHint().height()); l->setAlignment(AlignCenter); l->setFrameStyle(QFrame::WinPanel|QFrame::Sunken); l->setLineWidth(2);
+#define FORMATSLIDERLABEL(l) l->setFixedWidth(l->sizeHint().width()); l->setFixedHeight(QLineEdit(dummyWidget).sizeHint().height()); l->setAlignment(Qt::AlignCenter); l->setFrameStyle(QFrame::WinPanel|QFrame::Sunken); l->setLineWidth(2);
 
 ModemCommands::ModemCommands(QWidget *parent, const char *name)
-  : KDialogBase(parent, name, true, i18n("Edit Modem Commands"), Ok|Cancel)
+  : KDialog(parent)
 {
-  KWin::setIcons(winId(), kapp->icon(), kapp->miniIcon());
+    setObjectName(name);
+    setCaption( i18n("Edit Modem Commands") );
+    setButtons( Ok|Cancel );
+    setDefaultButton( Ok );
+    setModal( true );
+  KWindowSystem::setIcons(winId(), qApp->windowIcon().pixmap(IconSize(KIconLoader::Desktop),IconSize(KIconLoader::Desktop)), qApp->windowIcon().pixmap(IconSize(KIconLoader::Small),IconSize(KIconLoader::Small)));
   QWidget *dummyWidget = new QWidget(this);
   setMainWidget(dummyWidget);
 
@@ -56,13 +65,15 @@ ModemCommands::ModemCommands(QWidget *parent, const char *name)
   int row = 0;
 
   // toplevel layout
-  QVBoxLayout *tl = new QVBoxLayout(dummyWidget, 10, 4);
+  QVBoxLayout *tl = new QVBoxLayout(dummyWidget);
+  tl->setSpacing(4);
+  tl->setMargin(10);
 
   // add grid + frame
-  QGridLayout *l1 = new QGridLayout(GRIDROWS, 4);
+  QGridLayout *l1 = new QGridLayout();
   tl->addLayout(l1);
-  box = new QGroupBox(dummyWidget, "box");
-  l1->addMultiCellWidget(box, row++, GRIDROWS, 0, 3);
+  box = new Q3GroupBox(dummyWidget, "box");
+  l1->addWidget(box, row++, 0, GRIDROWS + 1, 4);
 
   // put slider and label into a separate H-Box
   QHBoxLayout *l2 = new QHBoxLayout;
@@ -70,8 +81,12 @@ ModemCommands::ModemCommands(QWidget *parent, const char *name)
   lpreinitslider = new QLabel("MMMM", dummyWidget);
   FORMATSLIDERLABEL(lpreinitslider);
 
-  preinitslider = new QSlider(0, 300, 1, 0,
-                                       QSlider::Horizontal, dummyWidget);
+  preinitslider = new QSlider(Qt::Horizontal, dummyWidget);
+  preinitslider->setMinimum(0);
+  preinitslider->setMaximum(300);
+  preinitslider->setPageStep(1);
+  preinitslider->setValue(0);
+
   preinitslider->setFixedHeight(preinitslider->sizeHint().height());
   connect(preinitslider, SIGNAL(valueChanged(int)),
 	  lpreinitslider, SLOT(setNum(int)));
@@ -83,7 +98,7 @@ ModemCommands::ModemCommands(QWidget *parent, const char *name)
 
   for(int i = 0; i < PPPData::NumInitStrings; i++) {
       initstr[i] = new QLineEdit(dummyWidget);
-      QLabel *initLabel = new QLabel(i18n("Initialization string %1:").arg(i + 1),
+      QLabel *initLabel = new QLabel(i18n("Initialization string %1:", i + 1),
 				    dummyWidget);
       ADJUSTEDIT(initstr[i]);
       l1->addWidget(initLabel, row, 1);
@@ -94,8 +109,12 @@ ModemCommands::ModemCommands(QWidget *parent, const char *name)
   l1->addLayout(l3, row, 2);
   linitslider = new QLabel("MMMM", dummyWidget);
   FORMATSLIDERLABEL(linitslider);
-  initslider = new QSlider(1, 300, 1, 0,
-				QSlider::Horizontal, dummyWidget);
+  initslider = new QSlider(Qt::Horizontal, dummyWidget);
+  initslider->setMinimum(1);
+  initslider->setMaximum(300);
+  initslider->setPageStep(1);
+  initslider->setValue(1); // was zero before the Qt4 port.
+
   initslider->setFixedHeight(initslider->sizeHint().height());
   connect(initslider, SIGNAL(valueChanged(int)),
 	  linitslider, SLOT(setNum(int)));
@@ -110,8 +129,12 @@ ModemCommands::ModemCommands(QWidget *parent, const char *name)
   l1->addLayout(l4, row, 2);
   ldurationslider = new QLabel("MMMM", dummyWidget);
   FORMATSLIDERLABEL(ldurationslider);
-  durationslider = new QSlider(1, 255, 1, 0,
-				QSlider::Horizontal, dummyWidget);
+  durationslider = new QSlider(Qt::Horizontal, dummyWidget);
+  durationslider->setMinimum(1);
+  durationslider->setMaximum(255);
+  durationslider->setPageStep(1);
+  durationslider->setValue(1); // was 0 before the Qt4 port
+
   durationslider->setFixedHeight(durationslider->sizeHint().height());
   connect(durationslider, SIGNAL(valueChanged(int)),
 	  ldurationslider, SLOT(setNum(int)));
@@ -226,8 +249,12 @@ ModemCommands::ModemCommands(QWidget *parent, const char *name)
   lslider = new QLabel("MMMM", dummyWidget);
   FORMATSLIDERLABEL(lslider);
 
-  slider = new QSlider(0, 255, 1, 0,
-				QSlider::Horizontal, dummyWidget);
+  slider = new QSlider(Qt::Horizontal, dummyWidget);
+  slider->setMinimum(0);
+  slider->setMaximum(255);
+  slider->setPageStep(1);
+  slider->setValue(0);
+
   slider->setFixedHeight(slider->sizeHint().height());
   connect(slider, SIGNAL(valueChanged(int)),
 	  lslider, SLOT(setNum(int)));
@@ -256,10 +283,10 @@ ModemCommands::ModemCommands(QWidget *parent, const char *name)
 
   initstr[0]->setFocus();
 
-  l1->addColSpacing(0, 10);
-  l1->addColSpacing(3, 10);
-  l1->addRowSpacing(0, 5);
-  l1->addRowSpacing(GRIDROWS, 5);
+  l1->addItem(new QSpacerItem(10,0), 0, 0);
+  l1->addItem(new QSpacerItem(10,0), 0, 3);
+  l1->addItem(new QSpacerItem(0, 5), 0, 0);
+  l1->addItem(new QSpacerItem(0, 5), GRIDROWS, 0);
 
   //set stuff from gpppdata
   preinitslider->setValue(gpppdata.modemPreInitDelay());
@@ -298,9 +325,11 @@ ModemCommands::ModemCommands(QWidget *parent, const char *name)
   volume_off->setText(gpppdata.volumeOff());
   volume_medium->setText(gpppdata.volumeMedium());
   volume_high->setText(gpppdata.volumeHigh());
-	
+
 	// Save the data, so if it not exist we save the default
 	gpppdata.save();
+	connect(this,SIGNAL(okClicked()),this,SLOT(slotOk()));
+	connect(this,SIGNAL(cancelClicked()),this,SLOT(slotCancel()));
 }
 
 
