@@ -28,17 +28,18 @@
 
 static QString outputErrorMessageString;
 
-static uint8_t *buf = 0;
-
 static rfbBool newclient(rfbClient *cl)
 {
+    VncClientThread *t = (VncClientThread*)rfbClientGetClientData(cl, 0);
+    Q_ASSERT(t);
+
     int width = cl->width, height = cl->height, depth = cl->format.bitsPerPixel;
     int size = width * height * (depth / 8);
-    if (cl->frameBuffer)
-        delete [] buf; // do not leak if we get a new framebuffer size
-    buf = new uint8_t[size];
-    memset(buf, '\0', size);
-    cl->frameBuffer = buf;
+    if (t->frameBuffer)
+        delete [] t->frameBuffer; // do not leak if we get a new framebuffer size
+    t->frameBuffer = new uint8_t[size];
+    cl->frameBuffer = t->frameBuffer;
+    memset(cl->frameBuffer, '\0', size);
     cl->format.bitsPerPixel = 32;
     cl->format.redShift = 16;
     cl->format.greenShift = 8;
@@ -47,8 +48,6 @@ static rfbBool newclient(rfbClient *cl)
     cl->format.greenMax = 0xff;
     cl->format.blueMax = 0xff;
 
-    VncClientThread *t = (VncClientThread*)rfbClientGetClientData(cl, 0);
-
     switch (t->quality()) {
     case RemoteView::High:
         cl->appData.useBGR233 = 0;
@@ -87,11 +86,8 @@ extern void updatefb(rfbClient* cl, int x, int y, int w, int h)
     if (img.isNull())
         kDebug(5011) << "image not loaded";
 
-
     VncClientThread *t = (VncClientThread*)rfbClientGetClientData(cl, 0);
-
-    if (!t)
-        return;
+    Q_ASSERT(t);
 
     t->setImage(img);
 
@@ -105,9 +101,7 @@ extern void cuttext(rfbClient* cl, const char *text, int textlen)
 
     if (!cutText.isEmpty()) {
         VncClientThread *t = (VncClientThread*)rfbClientGetClientData(cl, 0);
-
-        if (!t)
-            return;
+        Q_ASSERT(t);
 
         t->emitGotCut(cutText);
     }
@@ -118,9 +112,7 @@ char *VncClientThread::passwdHandler(rfbClient *cl)
     kDebug(5011) << "password request" << kBacktrace();
 
     VncClientThread *t = (VncClientThread*)rfbClientGetClientData(cl, 0);
-
-    if (!t)
-        return 0;
+    Q_ASSERT(t);
 
     t->passwordRequest();
     t->m_passwordError = true;
@@ -163,6 +155,7 @@ void VncClientThread::outputHandler(const char *format, ...)
 
 VncClientThread::VncClientThread(QObject *parent)
         : QThread(parent)
+        , frameBuffer(0)
 {
     QMutexLocker locker(&mutex);
     m_stopped = false;
@@ -177,6 +170,8 @@ VncClientThread::~VncClientThread()
 {
     stop();
     wait(500);
+    
+    delete [] frameBuffer;
 }
 
 void VncClientThread::checkOutputErrorMessage()
@@ -306,10 +301,7 @@ void VncClientThread::run()
 
     // Cleanup allocated resources
     locker.relock();
-    delete [] cl->frameBuffer;
-    cl->frameBuffer = 0;
     rfbClientCleanup(cl);
-    buf = 0;
     m_stopped = true;
 }
 
